@@ -17,16 +17,14 @@
 
 #include "ASFTagHelper.h"
 
-#include <asfattribute.h>
-
-#ifndef UTILITIES_BUILD
-    #include <QBuffer>
-#endif  //UTILITIES_BUILD
-
 #include "StringHelper.h"
 
-using namespace Meta::Tag;
+#include <QBuffer>
+#include <QImage>
 
+#include <asfattribute.h>
+
+using namespace Meta::Tag;
 
 ASFTagHelper::ASFTagHelper( TagLib::Tag *tag, TagLib::ASF::Tag *asfTag, Amarok::FileType fileType )
             : TagHelper( tag, fileType )
@@ -43,7 +41,6 @@ ASFTagHelper::ASFTagHelper( TagLib::Tag *tag, TagLib::ASF::Tag *asfTag, Amarok::
     m_fieldMap.insert( Meta::valScore,       TagLib::String( "FMPS/Rating_Amarok_Score" ) );
 
     m_uidFieldMap.insert( UIDAFT,            TagLib::String( "Amarok/AFTv1" ) );
-    m_uidFieldMap.insert( UIDMusicBrainz,    TagLib::String( "MusicBrainz/Track Id" ) );
 }
 
 Meta::FieldHash
@@ -94,11 +91,6 @@ ASFTagHelper::tags() const
         }
         else if( it->first == uidFieldName( UIDAFT ) && isValidUID( strValue, UIDAFT ) )
             data.insert( Meta::valUniqueId, strValue );
-        else if( it->first == uidFieldName( UIDMusicBrainz ) && isValidUID( strValue, UIDMusicBrainz ) )
-        {
-            if( !data.contains( Meta::valUniqueId ) ) // we prefer AFT uids
-                data.insert( Meta::valUniqueId, strValue.prepend( "mb-" ) );
-        }
     }
 
     return data;
@@ -149,7 +141,6 @@ ASFTagHelper::setTags( const Meta::FieldHash &changes )
     return modified;
 }
 
-#ifndef UTILITIES_BUILD
 bool
 ASFTagHelper::hasEmbeddedCover() const
 {
@@ -259,4 +250,3 @@ ASFTagHelper::setEmbeddedCover( const QImage &cover )
 
     return true;
 }
-#endif  //UTILITIES_BUILD
