@@ -23,12 +23,11 @@
 
 #include "MP4TagHelper.h"
 
-#ifndef UTILITIES_BUILD
-    #include <QBuffer>
-#endif  //UTILITIES_BUILD
-
 #include "StringHelper.h"
 
+#include <QBuffer>
+#include <QImage>
+
 using namespace Meta::Tag;
 
 MP4TagHelper::MP4TagHelper( TagLib::Tag *tag, TagLib::MP4::Tag *mp4Tag, Amarok::FileType fileType )
@@ -138,7 +137,6 @@ MP4TagHelper::setTags( const Meta::FieldHash &changes )
     return modified;
 }
 
-#ifndef UTILITIES_BUILD
 bool
 MP4TagHelper::hasEmbeddedCover() const
 {
@@ -205,4 +203,3 @@ MP4TagHelper::setEmbeddedCover( const QImage &cover )
 
     return true;
 }
-#endif  //UTILITIES_BUILD
