@@ -50,28 +50,27 @@ OpmlParser::run()
 bool
 OpmlParser::read( const KUrl &url )
 {
-    DEBUG_BLOCK
     m_url = url;
     if( m_url.isLocalFile() )
     {
         //read directly from local file
-        QFile *localFile = new QFile( m_url.toLocalFile() );
-        if( !localFile->open( QIODevice::ReadOnly ) )
+        QFile localFile( m_url.toLocalFile() );
+        if( !localFile.open( QIODevice::ReadOnly ) )
         {
             debug() << "failed to open local OPML file " << m_url.url();
             return false;
         }
 
-        return read( localFile );
+        return read( &localFile );
     }
 
     m_transferJob = KIO::get( m_url, KIO::Reload, KIO::HideProgressInfo );
 
-    connect( m_transferJob, SIGNAL( data( KIO::Job *, const QByteArray & ) ),
-             SLOT( slotAddData( KIO::Job *, const QByteArray & ) ) );
+    connect( m_transferJob, SIGNAL(data(KIO::Job*,QByteArray)),
+             SLOT(slotAddData(KIO::Job*,QByteArray)) );
 
-    connect( m_transferJob, SIGNAL( result( KJob * ) ),
-             SLOT( downloadResult( KJob * ) ) );
+    connect( m_transferJob, SIGNAL(result(KJob*)),
+             SLOT(downloadResult(KJob*)) );
 
     // parse data
     return read();
@@ -87,7 +86,6 @@ OpmlParser::read( QIODevice *device )
 void
 OpmlParser::slotAddData( KIO::Job *job, const QByteArray &data )
 {
-    DEBUG_BLOCK
     Q_UNUSED( job )
 
     QXmlStreamReader::addData( data );
@@ -248,8 +246,6 @@ OpmlParser::elementType() const
 bool
 OpmlParser::read()
 {
-    DEBUG_BLOCK
-
     m_buffer.clear();
     m_actionStack.clear();
     m_actionStack.push( &( OpmlParser::sd.startAction ) );
@@ -371,8 +367,6 @@ OpmlParser::beginText()
 void
 OpmlParser::beginOutline()
 {
-    DEBUG_BLOCK
-
     OpmlOutline *parent = m_outlineStack.empty() ? 0 : m_outlineStack.top();
     OpmlOutline *outline = new OpmlOutline( parent );
     //adding outline to stack
@@ -392,14 +386,12 @@ OpmlParser::beginOutline()
 void
 OpmlParser::beginNoElement()
 {
-    DEBUG_BLOCK
     debug() << "no element expected here, but got element: " << QXmlStreamReader::name();
 }
 
 void
 OpmlParser::endDocument()
 {
-    debug() << "successfuly parsed OPML";
     emit doneParsing();
 }
 
