@@ -21,7 +21,7 @@
 
 #include <KStatusNotifierItem> // baseclass
 
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 #include "core/support/SmartPointerList.h"
 
 #include <QAction>
