@@ -26,7 +26,7 @@
 
 #include <QtXml/QXmlStreamReader>
 
-namespace Attica {
+namespace AmarokAttica {
 
 class EventParser
 {
