@@ -30,7 +30,7 @@
 #include <klocale.h>
 
 
-using namespace Attica;
+using namespace AmarokAttica;
 
 MessageListJob::MessageListJob()
   : m_job( 0 )
@@ -44,7 +44,7 @@ void MessageListJob::setUrl( const KUrl &url )
 
 void MessageListJob::start()
 {
-  QTimer::singleShot( 0, this, SLOT( doWork() ) );
+  QTimer::singleShot( 0, this, SLOT(doWork()) );
 }
 
 Message::List MessageListJob::messageList() const
@@ -57,10 +57,10 @@ void MessageListJob::doWork()
   qDebug() << m_url;
 
   m_job = KIO::get( m_url, KIO::NoReload, KIO::HideProgressInfo );
-  connect( m_job, SIGNAL( result( KJob * ) ),
-    SLOT( slotJobResult( KJob * ) ) );
-  connect( m_job, SIGNAL( data( KIO::Job *, const QByteArray & ) ),
-    SLOT( slotJobData( KIO::Job *, const QByteArray & ) ) );
+  connect( m_job, SIGNAL(result(KJob*)),
+    SLOT(slotJobResult(KJob*)) );
+  connect( m_job, SIGNAL(data(KIO::Job*,QByteArray)),
+    SLOT(slotJobData(KIO::Job*,QByteArray)) );
 }
 
 void MessageListJob::slotJobResult( KJob *job )
