@@ -17,9 +17,9 @@
 #include "BookmarkGroup.h"
 
 #include "AmarokUrl.h"
-#include "CollectionManager.h"
-#include "Debug.h"
-#include "SqlStorage.h"
+#include "core-impl/collections/support/CollectionManager.h"
+#include "core/support/Debug.h"
+#include "core/collections/support/SqlStorage.h"
 
 #include <typeinfo>
 
