@@ -24,11 +24,12 @@
 
 #include <QMap>
 
-class BrowserCategoryListDelegate;
+namespace Amarok {
+    class PrettyTreeView;
+}
 class SearchWidget;
 
 class QStackedWidget;
-class QTreeView;
 
 /**
  * This is a browser category that can contain other sub-categories
@@ -125,13 +126,12 @@ class BrowserCategoryList : public BrowserCategory
 
         SearchWidget *m_searchWidget;
         QStackedWidget *m_widgetStack;
-        QTreeView *m_categoryListView;
+        Amarok::PrettyTreeView *m_categoryListView;
 
         QMap<QString, BrowserCategory *> m_categories;
 
         BrowserCategoryListModel *m_categoryListModel;
         BrowserCategoryListSortFilterProxyModel* m_proxyModel;
-        BrowserCategoryListDelegate *m_delegate;
 
         QString m_infoHtmlTemplate;
 
