@@ -18,13 +18,16 @@
 #include "BrowserCategory.h"
 #include "core/support/Debug.h"
 
-BrowserCategoryListModel::BrowserCategoryListModel()
- : QAbstractListModel()
+#include "widgets/PrettyTreeRoles.h"
+
+BrowserCategoryListModel::BrowserCategoryListModel( QObject* parent )
+ : QAbstractListModel( parent )
 {
 }
 
 BrowserCategoryListModel::~BrowserCategoryListModel()
 {
+    qDeleteAll( m_categories );
 }
 
 int
@@ -49,19 +52,16 @@ BrowserCategoryListModel::data( const QModelIndex &index, int role ) const
         case Qt::DecorationRole:
             return QVariant( m_categories[index.row()]->icon() );
 
-        case CustomCategoryRoles::ShortDescriptionRole:
-        case CustomCategoryRoles::SortRole:
+        case PrettyTreeRoles::SortRole:
+        case PrettyTreeRoles::ByLineRole:
             return QVariant( m_categories[index.row()]->shortDescription() );
 
-        case CustomCategoryRoles::LongDescriptionRole:
+        case Qt::ToolTipRole:
             return QVariant( m_categories[index.row()]->longDescription() );
 
         case CustomCategoryRoles::CategoryRole:
             return qVariantFromValue( m_categories[index.row()] );
 
-        case CustomCategoryRoles::AlternateRowRole:
-            return ( index.row() % 2 == 1 );
-
         default:
             return QVariant();
      }
