@@ -744,6 +744,44 @@ CollectionTreeView::organizeTracks( const QSet<CollectionTreeItem *> &items ) co
     location->prepareMove( qm, coll->location() );
 }
 
+void
+CollectionTreeView::copySelectedToLocalCollection()
+{
+    DEBUG_BLOCK
+
+    // Get the local collection
+    Collections::Collection *collection = 0;
+    const QList<Collections::Collection*> collections = CollectionManager::instance()->collections().keys();
+
+    foreach( collection, collections )
+    {
+        if ( collection->collectionId() == "localCollection" )
+            break;
+    }
+
+    if( !collection )
+        return;
+
+    // Get selected items
+    QModelIndexList indexes = selectedIndexes();
+    if( m_filterModel )
+    {
+        QModelIndexList tmp;
+        foreach( const QModelIndex &idx, indexes )
+            tmp.append( m_filterModel->mapToSource( idx ) );
+        indexes = tmp;
+    }
+
+    m_currentItems.clear();
+    foreach( const QModelIndex &index, indexes )
+    {
+        if( index.isValid() && index.internalPointer() )
+            m_currentItems.insert( static_cast<CollectionTreeItem *>( index.internalPointer() ) );
+    }
+
+    copyTracks( m_currentItems, collection, false );
+}
+
 void
 CollectionTreeView::copyTracks( const QSet<CollectionTreeItem *> &items,
                                 Collection *destination, bool removeSources ) const
