@@ -27,13 +27,13 @@
 #include "browsers/CollectionTreeItemModelBase.h"
 #include "browsers/SingleCollectionTreeItemModel.h"
 #include "browsers/collectionbrowser/CollectionBrowserTreeView.h"
-#include "browsers/collectionbrowser/CollectionTreeItemDelegate.h"
 #include "core/meta/support/MetaConstants.h"
 #include "core/support/Amarok.h"
 #include "core/support/Debug.h"
-#include "core-impl/collections/proxycollection/ProxyCollection.h"
+#include "core-impl/collections/aggregate/AggregateCollection.h"
 #include "core-impl/collections/support/CollectionManager.h"
 #include "widgets/SearchWidget.h"
+#include "widgets/PrettyTreeDelegate.h"
 
 #include <KAction>
 #include <KIcon>
@@ -56,6 +56,8 @@ CollectionWidget *CollectionWidget::s_instance = 0;
 
 #define CATEGORY_LEVEL_COUNT 3
 
+Q_DECLARE_METATYPE( QList<CategoryId::CatMenuId> ) // needed to QAction payload
+
 class CollectionWidget::Private
 {
 public:
@@ -92,9 +94,10 @@ CollectionWidget::Private::view( CollectionWidget::ViewMode mode )
             v->setFrameShape( QFrame::NoFrame );
             v->setRootIsDecorated( false );
             connect( v, SIGNAL(leavingTree()), searchWidget->comboBox(), SLOT(setFocus()) );
-            CollectionTreeItemDelegate *delegate = new CollectionTreeItemDelegate( v );
+            PrettyTreeDelegate *delegate = new PrettyTreeDelegate( v );
             v->setItemDelegate( delegate );
             CollectionTreeItemModelBase *multiModel = new CollectionTreeItemModel( QList<CategoryId::CatMenuId>() );
+            multiModel->setParent( stack );
             v->setModel( multiModel );
             treeView = v;
         }
@@ -110,18 +113,19 @@ CollectionWidget::Private::view( CollectionWidget::ViewMode mode )
             v = new CollectionBrowserTreeView( stack );
             v->setAlternatingRowColors( true );
             v->setFrameShape( QFrame::NoFrame );
-            Collections::ProxyCollection *proxyColl = new Collections::ProxyCollection();
+            Collections::AggregateCollection *aggregateColl = new Collections::AggregateCollection();
             connect( CollectionManager::instance(),
                      SIGNAL(collectionAdded(Collections::Collection*,CollectionManager::CollectionStatus)),
-                     proxyColl,
+                     aggregateColl,
                      SLOT(addCollection(Collections::Collection*,CollectionManager::CollectionStatus)));
             connect( CollectionManager::instance(), SIGNAL(collectionRemoved(QString)),
-                     proxyColl, SLOT(removeCollection(QString)));
+                     aggregateColl, SLOT(removeCollection(QString)));
             foreach( Collections::Collection* coll, CollectionManager::instance()->viewableCollections() )
             {
-                proxyColl->addCollection( coll, CollectionManager::CollectionViewable );
+                aggregateColl->addCollection( coll, CollectionManager::CollectionViewable );
             }
-            CollectionTreeItemModelBase *singleModel = new SingleCollectionTreeItemModel( proxyColl, QList<CategoryId::CatMenuId>() );
+            CollectionTreeItemModelBase *singleModel = new SingleCollectionTreeItemModel( aggregateColl, QList<CategoryId::CatMenuId>() );
+            singleModel->setParent( stack );
             v->setModel( singleModel );
             singleTreeView = v;
         }
@@ -154,14 +158,6 @@ CollectionWidget::CollectionWidget( const QString &name , QWidget *parent )
     KHBox *hbox = new KHBox( this );
     d->stack = new QStackedWidget( this );
 
-    // -- read the view level settings from the configuration
-    QList<int> levelNumbers = Amarok::config( "Collection Browser" ).readEntry( "TreeCategory", QList<int>() );
-    QList<CategoryId::CatMenuId> levels;
-    foreach( int levelNumber, levelNumbers )
-        levels << CategoryId::CatMenuId( levelNumber );
-    if ( levels.isEmpty() )
-        levels << CategoryId::Artist << CategoryId::Album;
-
     // -- read the current view mode from the configuration
     const QMetaObject *mo = metaObject();
     const QMetaEnum me = mo->enumerator( mo->indexOfEnumerator( "ViewMode" ) );
@@ -169,11 +165,6 @@ CollectionWidget::CollectionWidget( const QString &name , QWidget *parent )
     int enumValue = me.keyToValue( value.toLocal8Bit().constData() );
     enumValue == -1 ? d->viewMode = NormalCollections : d->viewMode = (ViewMode) enumValue;
 
-    // FIXME Variable viewMode is never used. What was the intention?
-    ViewMode viewMode = NormalCollections;
-    if( enumValue != -1 )
-       viewMode = (ViewMode)enumValue;
-
     // -- the search widget
     d->searchWidget = new SearchWidget( hbox );
     d->searchWidget->setClickMessage( i18n( "Search collection" ) );
@@ -193,93 +184,82 @@ CollectionWidget::CollectionWidget( const QString &name , QWidget *parent )
 
     QMenu *filterMenu = new QMenu( 0 );
 
-    QAction *action = new QAction( i18n( "Artist / Album" ), this );
-    connect( action, SIGNAL( triggered( bool ) ), SLOT( sortByArtistAlbum() ) );
-    filterMenu->addAction( action );
-
-    action = new QAction( i18n( "Album / Artist" ), this );
-    connect( action, SIGNAL( triggered( bool ) ), SLOT( sortByAlbumArtist() ) );
-    filterMenu->addAction( action );
-
-    action = new QAction( i18n( "Genre / Artist" ), this );
-    connect( action, SIGNAL( triggered( bool ) ), SLOT( sortByGenreArtist() ) );
-    filterMenu->addAction( action );
-
-    action = new QAction( i18n( "Genre / Artist / Album" ), this );
-    connect( action, SIGNAL(triggered( bool ) ), SLOT( sortByGenreArtistAlbum() ) );
-    filterMenu->addAction( action );
-
+    using namespace CategoryId;
+    static const QList<QList<CatMenuId> > levelPresets = QList<QList<CatMenuId> >()
+        << ( QList<CatMenuId>() << CategoryId::AlbumArtist << CategoryId::Album )
+        << ( QList<CatMenuId>() << CategoryId::Album << CategoryId::Artist ) // album artist has no sense here
+        << ( QList<CatMenuId>() << CategoryId::Genre << CategoryId::AlbumArtist )
+        << ( QList<CatMenuId>() << CategoryId::Genre << CategoryId::AlbumArtist << CategoryId::Album );
+    foreach( const QList<CatMenuId> &levels, levelPresets )
+    {
+        QStringList categoryLabels;
+        foreach( CatMenuId category, levels )
+            categoryLabels << CollectionTreeItemModelBase::nameForCategory( category );
+        QAction *action = filterMenu->addAction( categoryLabels.join( i18nc(
+                "separator between collection browser level categories, i.e. the ' / ' "
+                "in 'Artist / Album'", " / " ) ) );
+        action->setData( QVariant::fromValue( levels ) );
+    }
+    // following catches all actions in the filter menu
+    connect( filterMenu, SIGNAL(triggered(QAction*)), SLOT(sortByActionPayload(QAction*)) );
     filterMenu->addSeparator();
 
+    // -- read the view level settings from the configuration
+    QList<CategoryId::CatMenuId> levels = readLevelsFromConfig();
+    if ( levels.isEmpty() )
+        levels << levelPresets.at( 0 ); // use first preset as default
+
     // -- generate the level menus
     d->menuLevel[0] = filterMenu->addMenu( i18n( "First Level" ) );
     d->menuLevel[1] = filterMenu->addMenu( i18n( "Second Level" ) );
     d->menuLevel[2] = filterMenu->addMenu( i18n( "Third Level" ) );
 
     // - fill the level menus
+    static const QList<CatMenuId> levelChoices = QList<CatMenuId>()
+            << CategoryId::AlbumArtist
+            << CategoryId::Artist
+            << CategoryId::Album
+            << CategoryId::Genre
+            << CategoryId::Composer
+            << CategoryId::Label;
     for( int i = 0; i < CATEGORY_LEVEL_COUNT; i++ )
     {
+        QList<CatMenuId> usedLevelChoices = levelChoices;
         QActionGroup *actionGroup = new QActionGroup( this );
+        if( i > 0 ) // skip first submenu
+            usedLevelChoices.prepend( CategoryId::None );
 
-        if( i > 0 )
+        QMenu *menuLevel = d->menuLevel[i];
+        foreach( CatMenuId level, usedLevelChoices )
         {
-            QAction *action = d->menuLevel[i]->addAction( i18n( "None" ) );
-            action->setData( CategoryId::None );
+            QAction *action = menuLevel->addAction( CollectionTreeItemModelBase::nameForCategory( level ) );
+            action->setData( QVariant::fromValue<CatMenuId>( level ) );
             action->setCheckable( true );
+            action->setChecked( ( levels.count() > i ) ? ( levels[i] == level )
+                    : ( level == CategoryId::None ) );
             actionGroup->addAction( action );
-
-            if( levels.count() <= i )
-                action->setChecked( true );
-        }
-
-        // - and now the different selections
-        struct LevelDefinition {
-            qint64 field;
-            CategoryId::CatMenuId menuId;
-        };
-        LevelDefinition definitions[] = { {Meta::valArtist, CategoryId::Artist},
-                                          {Meta::valAlbum, CategoryId::Album},
-                                          {Meta::valAlbumArtist, CategoryId::AlbumArtist},
-                                          {Meta::valGenre, CategoryId::Genre},
-                                          {Meta::valComposer, CategoryId::Composer},
-                                          {Meta::valLabel, CategoryId::Label} };
-
-        for( unsigned int j = 0; j < sizeof( definitions ) / sizeof( definitions[0] ); j++ )
-        {
-            QAction *action = d->menuLevel[i]->addAction( Meta::i18nForField( definitions[j].field ) );
-            action->setData( QVariant::fromValue<CategoryId::CatMenuId>( definitions[j].menuId ) );
-            action->setCheckable( true );
-            actionGroup->addAction( action );
-
-            if( levels.count() > i && levels[i] == definitions[j].menuId )
-                action->setChecked( true );
         }
 
         d->levelGroups[i] = actionGroup;
+        connect( menuLevel, SIGNAL(triggered(QAction*)), SLOT(sortLevelSelected(QAction*)) );
     }
 
-    connect( d->menuLevel[0], SIGNAL( triggered( QAction *) ), SLOT( sortLevelSelected( QAction * ) ) );
-    connect( d->menuLevel[1], SIGNAL( triggered( QAction *) ), SLOT( sortLevelSelected( QAction * ) ) );
-    connect( d->menuLevel[2], SIGNAL( triggered( QAction *) ), SLOT( sortLevelSelected( QAction * ) ) );
-
-
-    // -- create the checkboxes
-
+    // -- create the checkboxesh
     filterMenu->addSeparator();
     QAction *showYears = filterMenu->addAction( i18n( "Show Years" ) );
     showYears->setCheckable( true );
     showYears->setChecked( AmarokConfig::showYears() );
-    connect( showYears, SIGNAL( toggled( bool ) ), SLOT( slotShowYears( bool ) ) );
+    connect( showYears, SIGNAL(toggled(bool)), SLOT(slotShowYears(bool)) );
 
     QAction *showTrackNumbers = filterMenu->addAction( i18nc("@action:inmenu", "Show Track Numbers") );
     showTrackNumbers->setCheckable( true );
     showTrackNumbers->setChecked( AmarokConfig::showTrackNumbers() );
-    connect( showTrackNumbers, SIGNAL( toggled( bool ) ), SLOT( slotShowTrackNumbers( bool ) ) );
+    connect( showTrackNumbers, SIGNAL(toggled(bool)), SLOT(slotShowTrackNumbers(bool)) );
 
     QAction *showCovers = filterMenu->addAction( i18n( "Show Cover Art" ) );
     showCovers->setCheckable( true );
     showCovers->setChecked( AmarokConfig::showAlbumArt() );
-    connect( showCovers, SIGNAL(toggled(bool)), SLOT( slotShowCovers( bool ) ) );
+    connect( showCovers, SIGNAL(toggled(bool)), SLOT(slotShowCovers(bool)) );
 
 
     d->searchWidget->toolBar()->addSeparator();
@@ -288,7 +268,7 @@ CollectionWidget::CollectionWidget( const QString &name , QWidget *parent )
     toggleAction->setCheckable( true );
     toggleAction->setChecked( d->viewMode == CollectionWidget::UnifiedCollection );
     toggleView( d->viewMode == CollectionWidget::UnifiedCollection );
-    connect( toggleAction, SIGNAL( triggered( bool ) ), SLOT( toggleView( bool ) ) );
+    connect( toggleAction, SIGNAL(triggered(bool)), SLOT(toggleView(bool)) );
     d->searchWidget->toolBar()->addAction( toggleAction );
 
     KAction *searchMenuAction = new KAction( KIcon( "preferences-other" ), i18n( "Sort Options" ), this );
@@ -334,35 +314,11 @@ CollectionWidget::sortLevelSelected( QAction *action )
 }
 
 void
-CollectionWidget::sortByArtistAlbum()
+CollectionWidget::sortByActionPayload( QAction *action )
 {
-    QList<CategoryId::CatMenuId> levels;
-    levels << CategoryId::Artist << CategoryId::Album;
-    setLevels( levels );
-}
-
-void
-CollectionWidget::sortByAlbumArtist()
-{
-    QList<CategoryId::CatMenuId> levels;
-    levels << CategoryId::Album << CategoryId::Artist;
-    setLevels( levels );
-}
-
-void
-CollectionWidget::sortByGenreArtist()
-{
-    QList<CategoryId::CatMenuId> levels;
-    levels << CategoryId::Genre << CategoryId::Artist;
-    setLevels( levels );
-}
-
-void
-CollectionWidget::sortByGenreArtistAlbum()
-{
-    QList<CategoryId::CatMenuId> levels;
-    levels << CategoryId::Genre << CategoryId::Artist << CategoryId::Album;
-    setLevels( levels );
+    QList<CategoryId::CatMenuId> levels = action->data().value<QList<CategoryId::CatMenuId> >();
+    if( !levels.isEmpty() )
+        setLevels( levels );
 }
 
 void
@@ -407,6 +363,7 @@ CollectionWidget::levels() const
 void CollectionWidget::setLevels( const QList<CategoryId::CatMenuId> &levels )
 {
     // -- select the corrrect menu entries
+    QSet<CategoryId::CatMenuId> encounteredLevels;
     for( int i = 0; i < CATEGORY_LEVEL_COUNT; i++ )
     {
         CategoryId::CatMenuId category;
@@ -415,11 +372,16 @@ void CollectionWidget::setLevels( const QList<CategoryId::CatMenuId> &levels )
         else
             category = CategoryId::None;
 
-        foreach( QAction* action, d->levelGroups[i]->actions() )
+        foreach( QAction *action, d->levelGroups[i]->actions() )
         {
-            if( action->data().value<CategoryId::CatMenuId>() == category && !action->isChecked() )
-                action->setChecked( true );
+            CategoryId::CatMenuId actionCategory = action->data().value<CategoryId::CatMenuId>();
+            if( actionCategory == category )
+                action->setChecked( true ); // unchecks other actions in the same group
+            action->setEnabled( !encounteredLevels.contains( actionCategory ) );
         }
+
+        if( category != CategoryId::None )
+            encounteredLevels << category;
     }
 
     // -- set the levels in the view
@@ -433,11 +395,20 @@ void CollectionWidget::toggleView( bool merged )
     CollectionBrowserTreeView *oldView = d->view( d->viewMode );
 
     if( oldView )
+    {
         d->searchWidget->disconnect( oldView );
+        oldView->disconnect( d->searchWidget );
+    }
 
     CollectionBrowserTreeView *newView = d->view( newMode );
-    connect( d->searchWidget, SIGNAL( filterChanged( const QString & ) ),
-             newView, SLOT( slotSetFilter( const QString & ) ) );
+    connect( d->searchWidget, SIGNAL(filterChanged(QString)),
+             newView, SLOT(slotSetFilter(QString)) );
+    connect( d->searchWidget, SIGNAL(returnPressed()),
+             newView, SLOT(slotAddFilteredTracksToPlaylist()) );
+    // reset search string after successful adding of filtered items to playlist
+    connect( newView, SIGNAL(addingFilteredTracksDone()),
+             d->searchWidget, SLOT(setSearchString()) );
+
     if( d->stack->indexOf( newView ) == -1 )
         d->stack->addWidget( newView );
     d->stack->setCurrentWidget( newView );
@@ -458,4 +429,35 @@ void CollectionWidget::toggleView( bool merged )
     Amarok::config( "Collection Browser" ).writeEntry( "View Mode", me.valueToKey( d->viewMode ) );
 }
 
+QList<CategoryId::CatMenuId>
+CollectionWidget::readLevelsFromConfig() const
+{
+    QList<int> levelNumbers = Amarok::config( "Collection Browser" ).readEntry( "TreeCategory", QList<int>() );
+    QList<CategoryId::CatMenuId> levels;
+
+    // we changed "Track Artist" to "Album Artist" default before Amarok 2.8. Migrate user
+    // config mentioning Track Artist to Album Artist where it makes sense:
+    static const int OldArtistValue = 2;
+    bool albumOrAlbumArtistEncountered = false;
+    foreach( int levelNumber, levelNumbers )
+    {
+        CategoryId::CatMenuId category;
+        if( levelNumber == OldArtistValue )
+        {
+            if( albumOrAlbumArtistEncountered )
+                category = CategoryId::Artist;
+            else
+                category = CategoryId::AlbumArtist;
+        }
+        else
+            category = CategoryId::CatMenuId( levelNumber );
+
+        levels << category;
+        if( category == CategoryId::Album || category == CategoryId::AlbumArtist )
+            albumOrAlbumArtistEncountered = true;
+    }
+
+    return levels;
+}
+
 #include "CollectionWidget.moc"
