@@ -19,13 +19,7 @@
 
 #include "PlaylistBrowserCategory.h"
 
-#include <KDialog>
-
-#include <QModelIndex>
-#include <QPoint>
-#include <QSortFilterProxyModel>
-#include <QItemDelegate>
-#include <QWebPage>
+class QModelIndex;
 
 namespace PlaylistBrowserNS {
 
@@ -48,31 +42,11 @@ class PodcastCategory : public PlaylistBrowserCategory
         ~PodcastCategory();
 
     private slots:
-        void showInfo( const QModelIndex & index );
+        void showInfo( const QModelIndex &index );
         void slotImportOpml();
 };
 
-/**
-    A delegate for displaying the Podcast category
-
-    @author Bart Cerneels
- */
-class PodcastCategoryDelegate : public QItemDelegate
-{
-    public:
-        PodcastCategoryDelegate( QTreeView *view );
-        ~PodcastCategoryDelegate();
-
-        void paint( QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index ) const;
-        QSize sizeHint( const QStyleOptionViewItem &option, const QModelIndex &index ) const;
-
-    private:
-        QTreeView *m_view;
-        mutable int m_lastHeight;
-        QWebPage *m_webPage;
-};
-
-}
+} // namespace PlaylistBrowserNS
 
 namespace The {
     PlaylistBrowserNS::PodcastCategory *podcastCategory();
