@@ -60,9 +60,6 @@ class ServiceBrowser : public BrowserCategoryList
          */
         void resetService( const QString &name );
 
-        QString activeServiceFilter();
-        QList<int> activeServiceLevels();
-
     public slots:
 
         /**
@@ -83,10 +80,7 @@ class ServiceBrowser : public BrowserCategoryList
 
         static ServiceBrowser    *s_instance;
 
-        QTreeView                *m_serviceListView;
-
         ScriptableServiceManager *m_scriptableServiceManager;
-        bool                      m_usingContextView;
 
         QTimer m_filterTimer;
 
