@@ -16,7 +16,7 @@
 
 #include "Containment.h"
 
-#include "Debug.h"
+#include "core/support/Debug.h"
 
 #include <plasma/corona.h>
 
