@@ -24,6 +24,8 @@
 
 #include "ContextView.h"
 
+#include "config.h"
+
 #include "Context.h"
 #include "ContextScene.h"
 #include "Svg.h"
@@ -211,7 +213,7 @@ ContextView::loadConfig()
         if( containment )
         {
             KConfigGroup cg( &conf, QString( "Containment %1" ).arg( i ) );
-
+#ifdef QT_QTOPENGL_FOUND
             // Special case: If this is the first time that the user runs an Amarok version
             // containing the Analyzer applet, modify the user's config so that the applet
             // will become active. We do this for discoverability and prettiness.
@@ -219,8 +221,6 @@ ContextView::loadConfig()
             const bool firstTimeWithAnalyzer = Amarok::config( "Context View" ).readEntry( "firstTimeWithAnalyzer", true );
             if( firstTimeWithAnalyzer )
             {
-                Amarok::config( "Context View" ).writeEntry( "firstTimeWithAnalyzer", false );
-
                 // Check if the Phonon backend implements all features required by the analyzer
                 Phonon::AudioDataOutput out;
                 const bool phononCanHandleAnalyzer = out.isValid();
@@ -228,6 +228,8 @@ ContextView::loadConfig()
                 QStringList plugins = cg.readEntry( "plugins", QStringList() );
                 if( phononCanHandleAnalyzer && !plugins.contains( "analyzer" ) )
                 {
+                    Amarok::config( "Context View" ).writeEntry( "firstTimeWithAnalyzer", false );
+
                     // Put the Analyzer applet at position #2, which is most likely below the Currenttrack applet.
                     if( !plugins.empty() )
                         plugins.insert( 1, "analyzer" );
@@ -235,6 +237,7 @@ ContextView::loadConfig()
                     cg.writeEntry( "plugins", plugins );
                 }
             }
+#endif
             containment->loadConfig( cg );
         }
     }
