@@ -15,19 +15,23 @@
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
  ****************************************************************************************/
 
+#define DEBUG_PREFIX "InfoApplet"
+
 #include "InfoApplet.h"
 
-#include "core/support/Amarok.h"
 #include "App.h"
 #include "amarokurls/AmarokUrl.h"
+#include "core/support/Amarok.h"
 #include "core/support/Debug.h"
 #include "PaletteHandler.h"
 #include "playlist/PlaylistController.h"
 
+#include <KGraphicsWebView>
 #include <KStandardDirs>
 
 #include <QPainter>
 #include <QDesktopServices>
+#include <QGraphicsLinearLayout>
 
 QString InfoApplet::s_defaultHtml = "<html>"
                                     "    <head>"
@@ -42,11 +46,8 @@ InfoApplet::InfoApplet( QObject* parent, const QVariantList& args )
     : Context::Applet( parent, args )
     , m_webView( 0 )
     , m_initialized( false )
-    , m_currentPlaylist( 0 )
-   
 {
     setHasConfigurationInterface( false );
-    setBackgroundHints( Plasma::Applet::NoBackground );
 }
 
 InfoApplet::~InfoApplet()
@@ -55,34 +56,31 @@ InfoApplet::~InfoApplet()
 }
 
 
-void  InfoApplet::init()
+void InfoApplet::init()
 {
+    // Call the base implementation.
+    Context::Applet::init();
 
     dataEngine( "amarok-info" )->connectSource( "info", this );
 
-    m_webView = new AmarokWebView( this );
-
-    resize( 500, -1 );
+    m_webView = new KGraphicsWebView( this );
 
     QPalette p = m_webView->palette();
     p.setColor( QPalette::Dark, QColor( 255, 255, 255, 0)  );
     p.setColor( QPalette::Window, QColor( 255, 255, 255, 0)  );
     m_webView->setPalette( p );
 
-    connect( m_webView->page(), SIGNAL( linkClicked ( const QUrl & ) ), SLOT( linkClicked ( const QUrl & ) ) );
+    QGraphicsLinearLayout *layout = new QGraphicsLinearLayout( Qt::Vertical, this );
+    layout->addItem( m_webView );
 
-    constraintsEvent();
+    connect( m_webView->page(), SIGNAL(linkClicked(QUrl)), SLOT(linkClicked(QUrl)) );
+
+    updateConstraints();
 }
 
 void InfoApplet::constraintsEvent( Plasma::Constraints constraints )
 {
     Q_UNUSED( constraints )
-    
-    prepareGeometryChange();
-
-    m_webView->setPos( standardPadding(), standardPadding() );
-    m_webView->resize( boundingRect().width() - 2 * standardPadding(), boundingRect().height() - 2 * standardPadding() );
-
     m_initialized = true;
 }
 
@@ -93,7 +91,7 @@ void InfoApplet::dataUpdated( const QString& name, const Plasma::DataEngine::Dat
     if( data.isEmpty() )
         return;
 
-    if  ( m_initialized )
+    if( m_initialized )
     {
         QString currentHtml = data[ "main_info" ].toString();
         if ( !currentHtml.isEmpty() )
@@ -119,31 +117,6 @@ void InfoApplet::dataUpdated( const QString& name, const Plasma::DataEngine::Dat
     }
 }
 
-void InfoApplet::paintInterface( QPainter *p, const QStyleOptionGraphicsItem *option, const QRect &contentsRect )
-{    
-    Q_UNUSED( option );
-
-    //bail out if there is no room to paint. Prevents crashes and really there is no sense in painting if the
-    //context view has been minimized completely
-    if ( ( contentsRect.width() < 40 ) || ( contentsRect.height() < 40 ) )
-    {
-        debug() << "Too little room to paint, hiding all children ( making myself invisible but still painted )!";
-        foreach ( QGraphicsItem * childItem, QGraphicsItem::children() )
-            childItem->hide();
-
-        return;
-    }
-    else
-    {
-        foreach ( QGraphicsItem * childItem, QGraphicsItem::children () )
-            childItem->show();
-    }
-
-    p->setRenderHint( QPainter::Antialiasing );
-
-    addGradientToAppletBackground( p );
-}
-
 void InfoApplet::linkClicked( const QUrl & url )
 {
     DEBUG_BLOCK
@@ -156,11 +129,11 @@ void InfoApplet::linkClicked( const QUrl & url )
     }
     else if ( url.toString().contains( ".xspf", Qt::CaseInsensitive ) )
     {
-        new Playlists::XSPFPlaylist( url, true );
+        // FIXME: this doesn't work (triggerTrackLoad is not called) and leaks the playlist instance
+        new Playlists::XSPFPlaylist( url, 0, Playlists::XSPFPlaylist::AppendToPlaylist );
     }
     else
         QDesktopServices::openUrl( url.toString() );
 }
 
 #include "InfoApplet.moc"
-
