@@ -54,9 +54,11 @@ private:
     Q_PRIVATE_SLOT( d_ptr, void _changeLyricsAlignment() )
     Q_PRIVATE_SLOT( d_ptr, void _closeLyrics() )
     Q_PRIVATE_SLOT( d_ptr, void _saveLyrics() )
+    Q_PRIVATE_SLOT( d_ptr, void _toggleAutoScroll() )
     Q_PRIVATE_SLOT( d_ptr, void _suggestionChosen(LyricsSuggestion) )
     Q_PRIVATE_SLOT( d_ptr, void _unsetCursor() )
     Q_PRIVATE_SLOT( d_ptr, void _trackDataChanged( Meta::TrackPtr ) )
+    Q_PRIVATE_SLOT( d_ptr, void _trackPositionChanged( qint64 position, bool userSeek ) )
     Q_PRIVATE_SLOT( d_ptr, void _lyricsChangedMessageButtonPressed(const Plasma::MessageButton) )
     Q_PRIVATE_SLOT( d_ptr, void _refetchMessageButtonPressed(const Plasma::MessageButton) )
 };
