@@ -20,7 +20,7 @@
 
 #include "ContextObserver.h"
 #include "context/DataEngine.h"
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 
 #include <kio/job.h>
 
@@ -69,6 +69,6 @@ private:
     
 };
 
-K_EXPORT_AMAROK_DATAENGINE( songkick, SongkickEngine )
+AMAROK_EXPORT_DATAENGINE( songkick, SongkickEngine )
 
 #endif
