@@ -16,8 +16,6 @@
 
 #include "AppletToolbarBase.h"
 
-#include "PaletteHandler.h"
-
 #include <QPainter>
 
 Context::AppletToolbarBase::AppletToolbarBase( QGraphicsItem* parent, Qt::WindowFlags wFlags )
@@ -38,7 +36,7 @@ Context::AppletToolbarBase::paint( QPainter* painter, const QStyleOptionGraphics
     painter->save();
     painter->setRenderHint( QPainter::Antialiasing );
 
-    QColor topColor = The::paletteHandler()->palette().color( QPalette::Button );
+    QColor topColor = palette().color( QPalette::Active, QPalette::Button );
     QColor bottomColor = topColor;
     topColor.setAlpha( 200 );
     bottomColor.setAlpha( 100 );
