@@ -587,7 +587,7 @@ SqlScanResultProcessor::deletedDirectories() const
         QString dir = res.at( 1 );
         // select all child directories
         query = QString( "SELECT id, deviceid, dir FROM directories WHERE deviceid = %1 "
-                "AND dir LIKE '%2_%'" ).arg( deviceId ).arg( dir );
+                "AND dir LIKE '%2_%'" ).arg( deviceId ).arg( storage->escape( dir ) );
         res = storage->query( query );
         for( int i = 0; i < res.count(); )
         {
@@ -695,6 +695,7 @@ SqlScanResultProcessor::cleanupMembers()
 {
     m_foundDirectories.clear();
     m_foundTracks.clear();
+    m_scannedDirectoryIds.clear();
     m_directoryIds.clear();
     m_albumIds.clear();
 
