@@ -24,24 +24,19 @@
 # if defined(MAKE_AMAROK_SQLCOLLECTION_LIB)
    /* We are building this library */
 #   define AMAROK_SQLCOLLECTION_EXPORT KDE_EXPORT
-
-#   if defined(DEBUG)
-#       define AMAROK_SQLCOLLECTION_EXPORT_TESTS KDE_EXPORT
-#   else
-#       define AMAROK_SQLCOLLECTION_EXPORT_TESTS
-#   endif
-
-
 # else
    /* We are using this library */
 #   define AMAROK_SQLCOLLECTION_EXPORT KDE_IMPORT
+# endif
+#endif
 
-#   if defined(DEBUG)
-#       define AMAROK_SQLCOLLECTION_EXPORT_TESTS KDE_IMPORT
-#   else
-#       define AMAROK_SQLCOLLECTION_EXPORT_TESTS
-#   endif
-
+#ifndef AMAROK_SQLCOLLECTION_MYSQLE_EXPORT
+# if defined(MAKE_AMAROK_COLLECTION_MYSQLECOLLECTION_LIB)
+   /* We are building this library */
+#   define AMAROK_SQLCOLLECTION_MYSQLE_EXPORT KDE_EXPORT
+# else
+   /* We are using this library */
+#   define AMAROK_SQLCOLLECTION_MYSQLE_EXPORT KDE_IMPORT
 # endif
 #endif
 
