@@ -39,7 +39,7 @@ MySqlServerCollectionFactory::init()
 {
     SqlCollectionFactory fac;
     SqlStorage *storage = new MySqlServerStorage();
-    SqlCollection *collection = fac.createSqlCollection( "localCollection", i18n( "Local Collection" ), storage );
+    SqlCollection *collection = fac.createSqlCollection( storage );
     m_initialized = true;
 
     emit newCollection( collection );
