@@ -17,7 +17,6 @@
 #ifndef METAMEDIADEVICEPLAYLIST_H
 #define METAMEDIADEVICEPLAYLIST_H
 
-#include "core/capabilities/Capability.h"
 #include "core/playlists/Playlist.h"
 
 #include "core/support/Debug.h"
@@ -38,25 +37,19 @@ namespace Playlists
 
             // Playlist Functions
             virtual QString name() const { return m_name; }
-            virtual QString prettyName() const { return m_name; }
-            virtual QString description() const { return QString(); }
             virtual KUrl uidUrl() const { return KUrl(); }
 
             /**override showing just the filename */
             virtual void setName( const QString &name );
 
-            /** returns all tracks in this playlist */
+            virtual int trackCount() const;
             virtual Meta::TrackList tracks();
             virtual void addTrack( Meta::TrackPtr track, int position = -1 );
 
             virtual void removeTrack( int position );
 
-	    bool hasCapabilityInterface( Capabilities::Capability::Type type ) const { Q_UNUSED( type ); return false; }
-        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) { Q_UNUSED( type ); return 0; }
-
     private:
         Meta::TrackList m_tracks;
-        QString m_description;
         QString m_name;
 
     };
