@@ -26,7 +26,6 @@
 
 #include <QSharedPointer>
 
-#include <KRandomSequence>
 #include <KSortableList>
 
 namespace Collections {
@@ -36,12 +35,9 @@ MemoryQueryMakerInternal::MemoryQueryMakerInternal( const QWeakPointer<MemoryCol
     , m_collection( collection )
     , m_matchers( 0 )
     , m_filters( 0 )
-    , m_randomize( false )
     , m_maxSize( 0 )
-    , m_returnAsDataPtrs( false )
     , m_type( QueryMaker::None )
     , m_albumQueryMode( QueryMaker::AllAlbums )
-    , m_artistQueryMode( QueryMaker::TrackArtists )
     , m_orderDescending( false )
     , m_orderByNumberField( false )
     , m_orderByField( 0 )
@@ -101,25 +97,11 @@ template <class PointerType>
 void MemoryQueryMakerInternal::emitProperResult( const QList<PointerType>& list )
 {
     QList<PointerType> resultList = list;
-    if( m_randomize )
-    {
-        KRandomSequence sequence;
-        sequence.randomize<PointerType>( resultList );
-    }
 
     if ( m_maxSize >= 0 && resultList.count() > m_maxSize )
         resultList = resultList.mid( 0, m_maxSize );
 
-    if( m_returnAsDataPtrs )
-    {
-        Meta::DataList data;
-        foreach( PointerType p, resultList )
-            data << Meta::DataPtr::staticCast( p );
-
-        emit newResultReady( m_collectionId, data );
-    }
-    else
-        emit newResultReady( m_collectionId, list );
+    emit newResultReady( list );
 }
 
 template<typename T>
@@ -173,11 +155,6 @@ MemoryQueryMakerInternal::handleResult()
                     else
                         tracks = MemoryQueryMakerHelper::orderListByString( tracks, m_orderByField, m_orderDescending );
                 }
-                if( m_randomize )
-                {
-                    KRandomSequence sequence;
-                    sequence.randomize<Meta::TrackPtr>( tracks );
-                }
 
                 int count = 0;
                 foreach( const Meta::TrackPtr &track, tracks )
@@ -192,7 +169,7 @@ MemoryQueryMakerInternal::handleResult()
                     count++;
                 }
             }
-            emit newResultReady( m_collectionId, result );
+            emit newResultReady( result );
             break;
         }
         case QueryMaker::Track :
@@ -464,11 +441,6 @@ MemoryQueryMakerInternal::handleResult( const Meta::TrackList &tmpTracks )
                     else
                         resultTracks = MemoryQueryMakerHelper::orderListByString( resultTracks, m_orderByField, m_orderDescending );
                 }
-                if( m_randomize )
-                {
-                    KRandomSequence sequence;
-                    sequence.randomize<Meta::TrackPtr>( resultTracks );
-                }
 
                 int count = 0;
                 foreach( const Meta::TrackPtr &track, resultTracks )
@@ -483,7 +455,7 @@ MemoryQueryMakerInternal::handleResult( const Meta::TrackList &tmpTracks )
                     count++;
                 }
             }
-            emit newResultReady( m_collectionId, result );
+            emit newResultReady( result );
             break;
         }
         case QueryMaker::Track :
@@ -613,24 +585,12 @@ MemoryQueryMakerInternal::setFilters( MemoryFilter *filters )
     m_filters = filters;
 }
 
-void
-MemoryQueryMakerInternal::setRandomize( bool randomize )
-{
-    m_randomize = randomize;
-}
-
 void
 MemoryQueryMakerInternal::setMaxSize( int maxSize )
 {
     m_maxSize = maxSize;
 }
 
-void
-MemoryQueryMakerInternal::setReturnAsDataPtrs( bool returnAsDataPtrs )
-{
-    m_returnAsDataPtrs = returnAsDataPtrs;
-}
-
 void
 MemoryQueryMakerInternal::setType( QueryMaker::QueryType type )
 {
