@@ -51,9 +51,7 @@ class UpnpTrack : public Meta::Track
         virtual KUrl playableUrl() const;
         virtual QString uidUrl() const;
         virtual QString prettyUrl() const;
-
-        virtual bool isPlayable() const;
-        virtual bool isEditable() const;
+        virtual QString notPlayableReason() const;
 
         virtual AlbumPtr album() const;
         virtual ArtistPtr artist() const;
