@@ -1,20 +1,18 @@
-/*
-    Copyright (C) 2010 Nikhil Marathe <nsm.nikhil@gmail.com>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/
+/****************************************************************************************
+ * Copyright (c) 2010 Nikhil Marathe <nsm.nikhil@gmail.com>                             *
+ *                                                                                      *
+ * This program is free software; you can redistribute it and/or modify it under        *
+ * the terms of the GNU General Public License as published by the Free Software        *
+ * Foundation; either version 2 of the License, or (at your option) any later           *
+ * version.                                                                             *
+ *                                                                                      *
+ * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
+ *                                                                                      *
+ * You should have received a copy of the GNU General Public License along with         *
+ * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
+ ****************************************************************************************/
 
 #define DEBUG_PREFIX "UpnpQueryMakerInternal"
 
@@ -75,9 +73,9 @@ void UpnpQueryMakerInternal::runQuery( KUrl query, bool filter )
     }
 
     KIO::ListJob *job = KIO::listDir( query, KIO::HideProgressInfo );
-    connect( job, SIGNAL( entries( KIO::Job *, const KIO::UDSEntryList & ) ),
-             this, SLOT( slotEntries( KIO::Job *, const KIO::UDSEntryList & ) ) );
-    connect( job, SIGNAL( result(KJob *) ), this, SLOT( slotDone(KJob *) ) );
+    connect( job, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
+             this, SLOT(slotEntries(KIO::Job*,KIO::UDSEntryList)) );
+    connect( job, SIGNAL(result(KJob*)), this, SLOT(slotDone(KJob*)) );
     queueJob( job );
 }
 
