@@ -16,140 +16,23 @@
 
 #include "PLSPlaylist.h"
 
-#include "core/capabilities/EditCapability.h"
-#include "core/meta/Meta.h"
 #include "core/support/Debug.h"
-#include "core-impl/collections/support/CollectionManager.h"
-#include "core-impl/meta/proxy/MetaProxy.h"
-#include "core-impl/playlists/types/file/PlaylistFileSupport.h"
-#include "playlistmanager/PlaylistManager.h"
 
-#include <KMimeType>
-#include <KLocale>
-
-#include <QTextStream>
-#include <QRegExp>
-#include <QString>
 #include <QFile>
 
-namespace Playlists {
+using namespace Playlists;
 
-PLSPlaylist::PLSPlaylist()
-    : m_url( Playlists::newPlaylistFilePath( "pls" ) )
-    , m_tracksLoaded( true )
+PLSPlaylist::PLSPlaylist( const KUrl &url, PlaylistProvider *provider )
+    : PlaylistFile( url, provider )
 {
-    m_name = m_url.fileName();
-}
-
-PLSPlaylist::PLSPlaylist( Meta::TrackList tracks )
-    : m_url( Playlists::newPlaylistFilePath( "pls" ) )
-    , m_tracksLoaded( true )
-    , m_tracks( tracks )
-{
-    m_name = m_url.fileName();
-}
-
-PLSPlaylist::PLSPlaylist( const KUrl &url )
-    : m_url( url )
-    , m_tracksLoaded( false )
-{
-    m_name = m_url.fileName();
-}
-
-PLSPlaylist::~PLSPlaylist()
-{
-}
-
-QString
-PLSPlaylist::description() const
-{
-    KMimeType::Ptr mimeType = KMimeType::mimeType( "audio/x-scpls" );
-    return QString( "%1 (%2)").arg( mimeType->name(), "pls" );
-}
-
-int
-PLSPlaylist::trackCount() const
-{
-    if( m_tracksLoaded )
-        return m_tracks.count();
-
-    //TODO: read NumberOfEntries from footer
-    return -1;
-}
-
-Meta::TrackList
-PLSPlaylist::tracks()
-{
-    return m_tracks;
-}
-
-void
-PLSPlaylist::triggerTrackLoad()
-{
-    //TODO make sure we've got all tracks first.
-    if( m_tracksLoaded )
-        return;
-
-    //check if file is local or remote
-    if( m_url.isLocalFile() )
-    {
-        QFile file( m_url.toLocalFile() );
-        if( !file.open( QIODevice::ReadOnly ) )
-        {
-            error() << "cannot open file";
-            return;
-        }
-
-        QString contents( file.readAll() );
-        file.close();
-
-        QTextStream stream;
-        stream.setString( &contents );
-        loadPls( stream );
-        m_tracksLoaded = true;
-    }
-    else
-    {
-        The::playlistManager()->downloadPlaylist( m_url, PlaylistFilePtr( this ) );
-    }
-}
-
-void
-PLSPlaylist::addTrack( Meta::TrackPtr track, int position )
-{
-    if( !m_tracksLoaded )
-        triggerTrackLoad();
-
-    int trackPos = position < 0 ? m_tracks.count() : position;
-    if( trackPos > m_tracks.count() )
-        trackPos = m_tracks.count();
-    m_tracks.insert( trackPos, track );
-    //set in case no track was in the playlist before
-    m_tracksLoaded = true;
-
-    notifyObserversTrackAdded( track, trackPos );
-
-    if( !m_url.isEmpty() )
-        saveLater();
-}
-
-void
-PLSPlaylist::removeTrack( int position )
-{
-    if( position < 0 || position >= m_tracks.count() )
-        return;
-    m_tracks.removeAt( position );
-
-    notifyObserversTrackRemoved( position );
-
-    if( !m_url.isEmpty() )
-        saveLater();
 }
 
 bool
 PLSPlaylist::loadPls( QTextStream &textStream )
 {
-    MetaProxy::TrackPtr proxyTrack;
+    if( m_tracksLoaded )
+        return true;
+    m_tracksLoaded = true;
 
     // Counted number of "File#=" lines.
     unsigned int entryCnt = 0;
@@ -207,15 +90,17 @@ PLSPlaylist::loadPls( QTextStream &textStream )
         numberOfEntries = entryCnt;
     }
     if( numberOfEntries == 0 )
+    {
         return true;
+    }
 
     unsigned int index;
     bool ok = false;
     bool inPlaylistSection = false;
 
+    MetaProxy::TrackPtr proxyTrack;
     /* Now iterate through all beautified lines in the buffer
-    * and parse the playlist data.
-    */
+     * and parse the playlist data. */
     QStringList::const_iterator i = lines.constBegin(), end = lines.constEnd();
     for( ; i != end; ++i )
     {
@@ -235,29 +120,23 @@ PLSPlaylist::loadPls( QTextStream &textStream )
             if( index > numberOfEntries || index == 0 )
                 continue;
             tmp = (*i).section( '=', 1 ).trimmed();
-            KUrl url( tmp );
-            if( url.isRelative() )
-            {
-                const QString dir = m_url.directory();
-                url = KUrl( dir );
-                url.addPath( tmp );
-                url.cleanPath();
-            }
+            KUrl url = getAbsolutePath( KUrl( tmp ) );
             proxyTrack = new MetaProxy::Track( url );
-            m_tracks << Meta::TrackPtr( proxyTrack.data() );
+            Meta::TrackPtr track( proxyTrack.data() );
+            addProxyTrack( track );
             continue;
         }
-        if( (*i).contains(regExp_Title) )
+        if( (*i).contains(regExp_Title) && proxyTrack )
         {
             // Have a "Title#=XYZ" line.
             index = loadPls_extractIndex(*i);
             if( index > numberOfEntries || index == 0 )
                 continue;
             tmp = (*i).section( '=', 1 ).trimmed();
-            proxyTrack->setName( tmp );
+            proxyTrack->setTitle( tmp );
             continue;
         }
-        if( (*i).contains( regExp_Length ) )
+        if( (*i).contains( regExp_Length ) && proxyTrack )
         {
             // Have a "Length#=XYZ" line.
             index = loadPls_extractIndex(*i);
@@ -286,28 +165,27 @@ PLSPlaylist::loadPls( QTextStream &textStream )
         }
         warning() << ".pls playlist: Unrecognized line: \"" << *i << "\"" << endl;
     }
-
     return true;
 }
 
-bool
-PLSPlaylist::save( const KUrl &location, bool relative )
+unsigned int
+PLSPlaylist::loadPls_extractIndex( const QString &str ) const
 {
-    Q_UNUSED( relative );
-
-    KUrl savePath = location;
-    //if the location is a directory append the name of this playlist.
-    if( savePath.fileName().isNull() )
-        savePath.setFileName( name() );
-
-    QFile file( savePath.path() );
-
-    if( !file.open( QIODevice::WriteOnly ) )
-    {
-        debug() << "Unable to write to playlist " << savePath.path();
-        return false;
-    }
+    /* Extract the index number out of a .pls line.
+     * Example:
+     *   loadPls_extractIndex("File2=foobar") == 2 */
+    bool ok = false;
+    unsigned int ret;
+    QString tmp( str.section( '=', 0, 0 ) );
+    tmp.remove( QRegExp( "^\\D*" ) );
+    ret = tmp.trimmed().toUInt( &ok );
+    Q_ASSERT(ok);
+    return ret;
+}
 
+void
+PLSPlaylist::savePlaylist( QFile &file )
+{
     //Format: http://en.wikipedia.org/wiki/PLS_(file_format)
     QTextStream stream( &file );
     //header
@@ -320,68 +198,16 @@ PLSPlaylist::save( const KUrl &location, bool relative )
         if( !track ) // see BUG: 303056
             continue;
 
-        KUrl playableUrl( track->playableUrl() );
-        QString file = playableUrl.url();
-
-        if( playableUrl.isLocalFile() )
-        {
-            if( relative )
-            {
-                file = KUrl::relativePath( savePath.directory(),
-                                           playableUrl.toLocalFile() );
-                if( file.startsWith( "./" ) )
-                    file.remove( 0, 2 );
-            }
-            else
-            {
-                file = playableUrl.toLocalFile();
-            }
-        }
-        stream << "File" << i << "=" << file;
+        stream << "File" << i << "=" << trackLocation( track );
         stream << "\nTitle" << i << "=";
         stream << track->name();
         stream << "\nLength" << i << "=";
         stream << track->length() / 1000;
         stream << "\n";
         i++;
-    }
-
-    //footer
-    stream << "NumberOfEntries=" << m_tracks.count() << endl;
-    stream << "Version=2\n";
-    file.close();
-    return true;
-}
-
-unsigned int
-PLSPlaylist::loadPls_extractIndex( const QString &str ) const
-{
-    /* Extract the index number out of a .pls line.
-     * Example:
-    *   loadPls_extractIndex("File2=foobar") == 2
-    */
-    bool ok = false;
-    unsigned int ret;
-    QString tmp( str.section( '=', 0, 0 ) );
-    tmp.remove( QRegExp( "^\\D*" ) );
-    ret = tmp.trimmed().toUInt( &ok );
-    Q_ASSERT(ok);
-    return ret;
-}
-
-bool
-PLSPlaylist::isWritable()
-{
-    if( m_url.isEmpty() )
-        return false;
-
-    return QFileInfo( m_url.path() ).isWritable();
-}
-
-void
-PLSPlaylist::setName( const QString &name )
-{
-    m_url.setFileName( name );
-}
+   }
 
+   //footer
+   stream << "NumberOfEntries=" << m_tracks.count() << endl;
+   stream << "Version=2\n";
 }
