@@ -17,7 +17,7 @@
 #ifndef METABOOKMARKTHISCAPABILITY_H
 #define METABOOKMARKTHISCAPABILITY_H
 
-#include "amarok_export.h"
+#include "core/amarokcore_export.h"
 #include "core/capabilities/Capability.h"
 
 #include <QAction>
