@@ -17,7 +17,7 @@
 #ifndef TRANSCODECAPABILITY_H
 #define TRANSCODECAPABILITY_H
 
-#include "amarok_export.h"
+#include "core/amarokcore_export.h"
 #include "core/capabilities/Capability.h"
 #include "core/transcoding/TranscodingConfiguration.h"
 
