@@ -17,9 +17,9 @@
 #ifndef TRACKFORURLWORKER_H
 #define TRACKFORURLWORKER_H
 
-#include "amarok_export.h"
+#include "core/amarokcore_export.h"
 #include "core/support/Amarok.h"
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 
 #include <KUrl>
 
