@@ -18,22 +18,15 @@
 #ifndef AMAROK_META_H
 #define AMAROK_META_H
 
-#include "amarok_export.h"
 #include "MetaReplayGain.h"
-
-#include "core/interfaces/MetaCapability.h"
+#include "core/meta/Base.h"
 
 #include <QList>
-#include <QMetaType>
 #include <QMutex>
 #include <QImage>
 #include <QDateTime>
-#include <QSet>
 #include <QSharedData>
-#include <QString>
-#include <QReadWriteLock>
 
-#include <KSharedPtr>
 #include <KUrl>
 
 namespace Collections
@@ -45,159 +38,9 @@ class PersistentStatisticsStore;
 
 namespace Meta
 {
-    class Base;
-    class Track;
-    class Artist;
-    class Album;
-    class Genre;
-    class Composer;
-    class Year;
-    class Label;
-
-    class Statistics;
-    typedef KSharedPtr<Statistics> StatisticsPtr;
-    typedef KSharedPtr<const Statistics> ConstStatisticsPtr;
-
-    typedef KSharedPtr<Base> DataPtr;
-    typedef QList<DataPtr> DataList;
-    typedef KSharedPtr<Track> TrackPtr;
-    typedef QList<TrackPtr> TrackList;
-    typedef KSharedPtr<Artist> ArtistPtr;
-    typedef QList<ArtistPtr> ArtistList;
-    typedef KSharedPtr<Album> AlbumPtr;
-    typedef QList<AlbumPtr> AlbumList;
-    typedef KSharedPtr<Composer> ComposerPtr;
-    typedef QList<ComposerPtr> ComposerList;
-    typedef KSharedPtr<Genre> GenrePtr;
-    typedef QList<GenrePtr> GenreList;
-    typedef KSharedPtr<Year> YearPtr;
-    typedef QList<YearPtr> YearList;
-    typedef KSharedPtr<Label> LabelPtr;
-    typedef QList<LabelPtr> LabelList;
-
-    class AMAROK_CORE_EXPORT Observer
-    {
-        friend class Base; // so that is can call destroyedNotify()
-
-        public:
-            virtual ~Observer();
-
-            /**
-             * Subscribe to changes made by @param entity.
-             *
-             * Changed in 2.7: being subscribed to an entity no longer prevents its
-             * destruction.
-             */
-            template <typename T>
-            void subscribeTo( KSharedPtr<T> entity ) { subscribeTo( entity.data() ); }
-            template <typename T>
-            void unsubscribeFrom( KSharedPtr<T> entity ) { unsubscribeFrom( entity.data() ); }
-
-            /**
-             * This method is called when the metadata of a track has changed.
-             * The called class may not cache the pointer.
-             */
-            virtual void metadataChanged( TrackPtr track );
-            virtual void metadataChanged( ArtistPtr artist );
-            virtual void metadataChanged( AlbumPtr album );
-            virtual void metadataChanged( GenrePtr genre );
-            virtual void metadataChanged( ComposerPtr composer );
-            virtual void metadataChanged( YearPtr year );
-
-            /**
-             * One of the subscribed entities was destroyed. You don't get which one
-             * because it is already invalid.
-             */
-            virtual void entityDestroyed();
-
-        private:
-            friend class ::PersistentStatisticsStore; // so that is can call KSharedPtr-free subscribe:
-            void subscribeTo( Base *ptr );
-            void unsubscribeFrom( Base *ptr );
-
-            /**
-             * Called in Meta::Base destructor so that Observer doesn't have a stale pointer.
-             */
-            void destroyedNotify( Base *ptr );
-
-            QSet<Base *> m_subscriptions;
-            QMutex m_subscriptionsMutex; /// mutex guarding access to m_subscriptions
-    };
-
-    class AMAROK_CORE_EXPORT Base : public virtual QSharedData, public MetaCapability
-    // virtual inherit. so that implementations can be both Meta::Track and Meta::Statistics
-    {
-        friend class Observer; // so that Observer can call (un)subscribe()
-
-        Q_PROPERTY( QString name READ name )
-        Q_PROPERTY( QString prettyName READ prettyName )
-        Q_PROPERTY( QString fullPrettyName READ fullPrettyName )
-        Q_PROPERTY( QString sortableName READ sortableName )
-
-        public:
-            Base();
-            virtual ~Base();
-
-            /** The textual label for this object.
-                For a track this is the track title, for an album it is the
-                album name.
-                If the name is unknown or unset then this returns an empty string.
-            */
-            virtual QString name() const = 0;
-
-            /** This is a nicer representation of the object.
-                We will try to prevent this name from being empty.
-                E.g. a track will fall back to the filename if possible.
-            */
-            virtual QString prettyName() const { return name(); };
-
-            /** A exact representation of the object.
-                This might include the artist name for a track or album.
-            */
-            virtual QString fullPrettyName() const { return prettyName(); }
-
-            /** A name that can be used for sorting.
-                This should usually mean that "The Beatles" is returned as "Beatles The"
-            */
-            virtual QString sortableName() const { return name(); }
-
-            /**used for showing a fixed name in the tree view. Needed for items that change
-             * their name occasionally such as some streams. These should overwrite this
-             */
-            virtual QString fixedName() const { return prettyName(); }
-
-        protected:
-            /**
-             * Subscribe @param observer for change updates. Don't ever think of calling
-             * this method yourself or overriding it, it's highly coupled with Observer.
-             */
-            void subscribe( Observer *observer );
-
-            /**
-             * Unsubscribe @param observer from change updates. Don't ever think of
-             * calling this method yourself or overriging it, it's highly coupled with
-             * Observer.
-             */
-            void unsubscribe( Observer *observer );
-
-            virtual void notifyObservers() const = 0;
-
-            template <typename T>
-            void notifyObserversHelper( const T *self ) const;
-
-        private:
-            // no copy allowed, since it's not safe with observer list
-            Q_DISABLE_COPY( Base )
-
-            QSet<Meta::Observer*> m_observers;
-            mutable QReadWriteLock m_observersLock; // guards access to m_observers
-    };
-
     class AMAROK_CORE_EXPORT Track : public Base
     {
         public:
-
-            virtual ~Track() {}
             /** used to display the trackname, should never be empty, returns prettyUrl() by default if name() is empty */
             virtual QString prettyName() const;
             /** an url which can be played by the engine backends */
@@ -211,10 +54,25 @@ namespace Meta
              */
             virtual QString uidUrl() const = 0;
 
-            /** Returns whether playableUrl() will return a playable Url
-                In principle this means that the url is valid.
+            /**
+             * Return whether playableUrl() will return a valid & readable playable url.
+             *
+             * Convenience method that just checks whether notPlayableReason() is empty.
              */
-            virtual bool isPlayable() const = 0;
+            bool isPlayable() const;
+
+            /**
+             * Return user-readable localized reason why isPlayable() is false.
+             *
+             * Subclasses must return a non-empty (localized) string if this track is not
+             * playable (i.e. playableUrl() won't return a valid url) and an empty string
+             * otherwise.
+             *
+             * This method is used to implement convenience Meta::Track::isPlayable()
+             * method.
+             */
+            virtual QString notPlayableReason() const = 0;
+
             /** Returns the album this track belongs to */
             virtual AlbumPtr album() const = 0;
             /** Returns the artist of this track */
@@ -239,7 +97,7 @@ namespace Meta
             virtual int filesize() const = 0;
             /** Returns the sample rate of this track */
             virtual int sampleRate() const = 0;
-            /** Returns the bitrate o this track */
+            /** Returns the bitrate o this track in kbps (kilo BITS per second) */
             virtual int bitrate() const = 0;
             /** Returns the time when the track was added to the collection,
                 or an invalid QDateTime if the time is not known. */
@@ -313,6 +171,18 @@ namespace Meta
 
             static bool lessThan( const TrackPtr& left, const TrackPtr& right );
 
+            /**
+             * Return a pointer to TrackEditor interface that allows you to edit metadata
+             * of this track. May be null, which signifies that the track is not editable.
+             *
+             * This is a replacement to ::create<Capabilities::EditCapability>() with more
+             * well-defined memory management and nicer implementation possibilities.
+             * (multiple inheritance and returning self)
+             *
+             * Default implementation returns null pointer.
+             */
+            virtual TrackEditorPtr editor();
+
             /**
              * Return a pointer to track's Statistics interface. May never be null.
              *
@@ -325,15 +195,24 @@ namespace Meta
             friend class ::PersistentStatisticsStore; // so that it can call notifyObservers
             virtual void notifyObservers() const;
 
+            /**
+             * Helper method for subclasses to implement notPlayableReason().
+             * Checks network status and returns a non-empty reason string if
+             * it isn't online.
+             */
+            QString networkNotPlayableReason() const;
+
+            /**
+             * Helper method for subclasses to implement notPlayableReason().
+             * Checks, in order, if the file exists, if it is a file and if
+             * the file is readable
+             */
+            QString localFileNotPlayableReason( const QString &path ) const;
     };
 
     class AMAROK_CORE_EXPORT Artist : public Base
     {
-        Q_PROPERTY( TrackList tracks READ tracks )
         public:
-
-            virtual ~Artist() {}
-
             virtual QString prettyName() const;
 
             /** returns all tracks by this artist */
@@ -350,35 +229,25 @@ namespace Meta
             mutable QString m_sortableName;
     };
 
-    /** Represents an album.
-        Most collections do not store a specific album object. Instead an album
-        is just a property of a track, a container containing one or more tracks.
-
-        Collections should proved an album for every track as the collection browser
-        will, depending on the setting, only display tracks inside albums.
-
-        For all albums in a compilation the pair album-title/album-artist should
-        be unique as this pair is used as a key in several places.
-
-        Albums without an artist are called compilations.
-        Albums without a title but with an artist should contain all singles of
-         the specific artist.
-        There should be one album without title and artist for all the rest.
-    */
+    /**
+     * Represents an album.
+     *
+     * Most collections do not store a specific album object. Instead an album is just
+     * a property of a track, a container containing one or more tracks.
+     *
+     * Collections should provide an album for every track as the collection browser
+     * will, depending on the setting, only display tracks inside albums.
+     *
+     * For all albums in a compilation the pair album-title/album-artist should be
+     * unique as this pair is used as a key in several places.
+     *
+     * Albums without an artist are called compilations. Albums without a title but
+     * with an artist should contain all singles of the specific artist. There should
+     * be one album without title and artist for all the rest.
+     */
     class AMAROK_CORE_EXPORT Album : public Base
     {
-        Q_PROPERTY( bool compilation READ isCompilation )
-        Q_PROPERTY( bool hasAlbumArtist READ hasAlbumArtist )
-        Q_PROPERTY( ArtistPtr albumArtist READ albumArtist )
-        Q_PROPERTY( TrackList tracks READ tracks )
-        Q_PROPERTY( bool hasImage READ hasImage )
-        // Q_PROPERTY( QPixmap image READ image WRITE setImage )
-        Q_PROPERTY( bool supressImageAutoFetch READ suppressImageAutoFetch WRITE setSuppressImageAutoFetch )
-
         public:
-            Album() {}
-            virtual ~Album() {}
-
             virtual QString prettyName() const;
 
             /**
@@ -448,11 +317,9 @@ namespace Meta
 
     class AMAROK_CORE_EXPORT Composer : public Base
     {
-        Q_PROPERTY( TrackList tracks READ tracks )
         public:
-
-            virtual ~Composer() {}
             virtual QString prettyName() const;
+
             /** returns all tracks by this composer */
             virtual TrackList tracks() = 0;
 
@@ -464,11 +331,9 @@ namespace Meta
 
     class AMAROK_CORE_EXPORT Genre : public Base
     {
-        Q_PROPERTY( TrackList tracks READ tracks )
         public:
-
-            virtual ~Genre() {}
             virtual QString prettyName() const;
+
             /** returns all tracks which belong to the genre */
             virtual TrackList tracks() = 0;
 
@@ -480,14 +345,11 @@ namespace Meta
 
     class AMAROK_CORE_EXPORT Year : public Base
     {
-        Q_PROPERTY( TrackList tracks READ tracks )
         public:
-
-            virtual ~Year() {}
-
-            /** Returns the year this object represents.
-                A number of 0 is considered unset.
-            */
+            /**
+             * Returns the year this object represents.
+             * number of 0 is considered unset.
+             */
             virtual int year() const { return name().toInt(); }
 
             /** returns all tracks which are tagged with this year */
@@ -500,27 +362,14 @@ namespace Meta
     };
 
     /**
-      A Label represents an arbitrary classification of a Track.
-      */
+     * A Label represents an arbitrary classification of a Track.
+     */
     class AMAROK_CORE_EXPORT Label : public Base
     {
-    public:
-        /**
-          Constructs a new Label.
-          */
-        Label() : Base() {}
-        /**
-          Destructs an existing Label.
-          */
-        virtual ~ Label() {}
-
-    protected:
-        virtual void notifyObservers() const;
+        // we need nothing more than what Meta::Base has
     };
 }
 
-Q_DECLARE_METATYPE( Meta::DataPtr )
-Q_DECLARE_METATYPE( Meta::DataList )
 Q_DECLARE_METATYPE( Meta::TrackPtr )
 Q_DECLARE_METATYPE( Meta::TrackList )
 Q_DECLARE_METATYPE( Meta::ArtistPtr )
@@ -536,6 +385,4 @@ Q_DECLARE_METATYPE( Meta::YearList )
 Q_DECLARE_METATYPE( Meta::LabelPtr )
 Q_DECLARE_METATYPE( Meta::LabelList )
 
-
-
 #endif /* AMAROK_META_H */
