@@ -141,6 +141,12 @@ CoverFetchPayload::~CoverFetchPayload()
 {
 }
 
+Meta::AlbumPtr
+CoverFetchPayload::album() const
+{
+    return m_album;
+}
+
 QString
 CoverFetchPayload::sanitizeQuery( const QString &query )
 {
@@ -468,7 +474,7 @@ CoverFetchArtPayload::prepareUrls()
 
     if( xml.hasError() )
     {
-        debug() << QString( "Error occured when pareparing %1 urls for %2: %3" )
+        debug() << QString( "Error occurred when preparing %1 urls for %2: %3" )
             .arg( sourceString(), (album() ? album()->name() : "'unknown'"), xml.errorString() );
         debug() << urls();
     }
