@@ -17,11 +17,13 @@
 #ifndef AMAROK_COVERFETCHUNIT_H
 #define AMAROK_COVERFETCHUNIT_H
 
-#include "core/meta/Meta.h"
+#include "core/meta/Meta.h" // for AlbumPtr default argument
 
 #include <KSharedPtr>
+#include <KUrl>
 
-#include <QtCore/QXmlStreamReader>
+#include <QStringList>
+#include <QXmlStreamReader>
 
 class CoverFetchPayload;
 class CoverFetchSearchPayload;
@@ -49,8 +51,8 @@ namespace CoverFetch
         Yahoo           //!< Use Yahoo! BOSS image search as provider
     };
 
-    typedef QHash< QString, QString > Metadata;
-    typedef QHash< KUrl, Metadata > Urls;
+    typedef QHash<QString, QString> Metadata;
+    typedef QHash<KUrl, Metadata> Urls;
 }
 
 /**
@@ -101,7 +103,7 @@ public:
     CoverFetchPayload( const Meta::AlbumPtr album, enum Type type, const CoverFetch::Source src );
     virtual ~CoverFetchPayload();
 
-    Meta::AlbumPtr album() const { return m_album; }
+    Meta::AlbumPtr album() const;
     CoverFetch::Source source() const;
     enum Type type() const;
     const CoverFetch::Urls &urls() const;
@@ -153,7 +155,7 @@ public:
     explicit CoverFetchSearchPayload( const QString &query = QString(),
                                       const CoverFetch::Source src = CoverFetch::LastFm,
                                       unsigned int page = 0,
-                                      Meta::AlbumPtr album = Meta::AlbumPtr(0) );
+                                      Meta::AlbumPtr album = Meta::AlbumPtr() );
     ~CoverFetchSearchPayload();
 
     QString query() const;
