@@ -20,7 +20,7 @@
 
 #include "core/support/Amarok.h"
 #include "core/support/Debug.h"
-#include "shared/TagsFromFileNameGuesser.h"
+#include "TagsFromFileNameGuesser.h"
 
 TagGuesser::TagGuesser()
           : m_guessed( false )
@@ -127,76 +127,3 @@ TagGuesser::convertTagCaseType( const QString &tag, int type )
     }
 }
 
-// creates a colored version of the filename
-QString
-TagGuesser::coloredFileName()
-{
-    if( m_guessed && !m_tags.isEmpty() )
-    {
-        QString coloredFileName = m_fileName;
-        Meta::FieldHash tags = Meta::Tag::TagGuesser::guessTagsByScheme( m_fileName, m_schema,
-                                                                         false, false );
-        foreach( qint64 key, tags.keys() )
-        {
-            QString value = tags[key].toString();
-            coloredFileName.replace( value, "<font color=\"" + fieldColor( key ) +
-                                            "\">" + value + "</font>", Qt::CaseInsensitive );
-        }
-        return coloredFileName;
-    }
-
-    return m_fileName;
-}
-
-QString
-TagGuesser::fieldColor( qint64 field )
-{
-    Qt::GlobalColor color;
-    switch ( field )
-    {
-        case Meta::valAlbum:
-            color = album_color;
-            break;
-
-        case Meta::valAlbumArtist:
-            color = albumartist_color;
-            break;
-
-        case Meta::valArtist:
-            color = artist_color;
-            break;
-
-        case Meta::valComment:
-            color = comment_color;
-            break;
-
-        case Meta::valComposer:
-            color = composer_color;
-            break;
-
-        case Meta::valDiscNr:
-            color = discnr_color;
-            break;
-
-        case Meta::valGenre:
-            color = genre_color;
-            break;
-
-        case Meta::valTitle:
-            color = title_color;
-            break;
-
-        case Meta::valTrackNr:
-            color = track_color;
-            break;
-
-        case Meta::valYear:
-            color = year_color;
-            break;
-
-        default:
-            color = Qt::black;
-    }
-
-    return QColor( color ).name();
-}
