@@ -131,7 +131,7 @@ Dynamic::BiasFactory::instance()
 Dynamic::ReplacementBias::ReplacementBias( const QString &n )
     : m_name( n )
 {
-    connect( BiasFactory::instance(), SIGNAL( changed() ), this, SLOT( factoryChanged() ) );
+    connect( BiasFactory::instance(), SIGNAL(changed()), this, SLOT(factoryChanged()) );
 }
 
 Dynamic::ReplacementBias::ReplacementBias( const QString &n, QXmlStreamReader *reader )
@@ -153,7 +153,7 @@ Dynamic::ReplacementBias::ReplacementBias( const QString &n, QXmlStreamReader *r
 
 debug() << "replacement bias for"<<n<<"is"<<m_html;
 
-    connect( BiasFactory::instance(), SIGNAL( changed() ), this, SLOT( factoryChanged() ) );
+    connect( BiasFactory::instance(), SIGNAL(changed()), this, SLOT(factoryChanged()) );
 }
 
 void
@@ -179,13 +179,13 @@ Dynamic::ReplacementBias::name() const
 QString
 Dynamic::ReplacementBias::toString() const
 {
-    return i18n( "Replacement for bias %1" ).arg( m_name );
+    return i18n( "Replacement for bias %1", m_name );
 }
 
 QWidget*
 Dynamic::ReplacementBias::widget( QWidget* parent )
 {
-    QLabel *label = new QLabel( i18n( "Replacement for bias %1" ).arg( m_name ), parent );
+    QLabel *label = new QLabel( i18n( "Replacement for bias %1", m_name ), parent );
 
     return label;
 }
