@@ -24,9 +24,8 @@
 #include <QImage>
 
 #include "core/support/Debug.h"
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 #include "EngineController.h"
-#include "core/engine/EngineObserver.h"
     
  // NOTE if not on mac, this whole file is useless, so not even going to try
 class GrowlInterface : QObject
