@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2009 Téo Mrnjavac <teo.mrnjavac@gmail.com>                             *
+ * Copyright (c) 2009 Téo Mrnjavac <teo@kde.org>                                        *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -26,7 +26,7 @@ namespace Playlist
 
 /**
  * A button that implements the non-menu part of the playlist breadcrumb item.
- * @author Téo Mrnjavac <teo.mrnjavac@gmail.com>
+ * @author Téo Mrnjavac <teo@kde.org>
  */
 class BreadcrumbItemSortButton : public BreadcrumbItemButton
 {
@@ -47,7 +47,7 @@ public:
      * otherwise false.
      * @param parent the parent QWidget.
      */
-    BreadcrumbItemSortButton( const QIcon &icon, const QString &text, bool noArrows, QWidget *parent );
+    BreadcrumbItemSortButton( const QIcon &icon, const QString &text, QWidget *parent );
 
     /**
      * Destructor.
@@ -79,20 +79,49 @@ signals:
     void arrowToggled( Qt::SortOrder );
 
 protected:
+    /**
+     * Repaints the widget.
+     * @param event the triggered QPaintEvent as provided by Qt.
+     */
     virtual void paintEvent( QPaintEvent *event );
+
+    /**
+     * Checks if the mouse is hovering the arrow rectangle.
+     * @param e the triggered QMouseEvent as provided by Qt.
+     */
+    virtual void mouseMoveEvent( QMouseEvent *e );
+
+    /**
+     * Handles the beginning of a mouse click.
+     * @param e the triggered QMouseEvent as provided by Qt.
+     */
     virtual void mousePressEvent( QMouseEvent *e );
+
+    /**
+     * Handles the release of the mouse button which completes a click action.
+     * @param e the triggered QMouseEvent as provided by Qt.
+     */
     virtual void mouseReleaseEvent( QMouseEvent *e );
 
+    /**
+     * Reimplemented from BreadcrumbItemButton, handles the painting of the widget's
+     * background, used by paintEvent().
+     * @param painter the QPainter object used by paintEvent().
+     */
+    virtual void drawHoverBackground( QPainter *painter );
+
 private:
     /**
      * Common initialization method, called by every constructor.
      */
     void init();
     Qt::SortOrder m_order;
-    bool m_noArrows;
-    QRect m_arrowRect;
-    QPoint m_pressedPos;
+    QRect m_arrowRect;      //!< the QRect that contains the order inversion arrow primitive.
+    QPoint m_pressedPos;    //!< the position of the last mousePressEvent, for handling clicks.
     bool m_arrowPressed;
+    bool m_arrowHovered;    //!< is the arrow rect hovered?
+    int m_arrowWidth;
+    int m_arrowHeight;
 };
 
 }   //namespace Playlist
