@@ -199,7 +199,8 @@ Controller::insertOptioned( Meta::TrackList list, AddOptions options )
     EngineController *engine = The::engineController();
     if( options.testFlag( DirectPlay ) ) // implies PrependToQueue
         startPlaying = true;
-    else if( options.testFlag( StartPlay ) && engine && !engine->isPlaying() )
+    else if( options.testFlag( Playlist::StartPlayIfConfigured )
+             && AmarokConfig::startPlayingOnAdd() && engine && !engine->isPlaying() )
     {
         // if nothing is in the queue, queue the first item we have added so that the call
         // to ->requestUserNextTrack() pops it. The queueing is therefore invisible to
@@ -227,8 +228,11 @@ Controller::insertOptioned( Playlists::PlaylistList list, AddOptions options )
 {
     TrackLoader::Flags flags;
     // if we are going to play, we need full metadata (playable tracks)
-    if( options.testFlag( DirectPlay ) )
+    if( options.testFlag( DirectPlay ) || ( options.testFlag( Playlist::StartPlayIfConfigured )
+        && AmarokConfig::startPlayingOnAdd() ) )
+    {
         flags |= TrackLoader::FullMetadataRequired;
+    }
     if( options.testFlag( Playlist::RemotePlaylistsAreStreams ) )
         flags |= TrackLoader::RemotePlaylistsAreStreams;
     TrackLoader *loader = new TrackLoader( flags ); // auto-deletes itself
@@ -249,8 +253,11 @@ Controller::insertOptioned( QList<KUrl> &urls, AddOptions options )
 {
     TrackLoader::Flags flags;
     // if we are going to play, we need full metadata (playable tracks)
-    if( options.testFlag( DirectPlay ) )
+    if( options.testFlag( DirectPlay ) || ( options.testFlag( Playlist::StartPlayIfConfigured )
+        && AmarokConfig::startPlayingOnAdd() ) )
+    {
         flags |= TrackLoader::FullMetadataRequired;
+    }
     if( options.testFlag( Playlist::RemotePlaylistsAreStreams ) )
         flags |= TrackLoader::RemotePlaylistsAreStreams;
     TrackLoader *loader = new TrackLoader( flags ); // auto-deletes itself
@@ -596,20 +603,9 @@ Controller::insertionHelper( int bottomModelRow, Meta::TrackList& tl )
         i.next();
         Meta::TrackPtr track = i.value();
 
-        if ( track == Meta::TrackPtr() )
-        { /*ignore*/ }
-
-        else if( Playlists::canExpand( track ) )
+        if( !track )
         {
-            Playlists::PlaylistPtr playlist = Playlists::expand( track ); //expand() can return 0 if the KIO job times out
-            if( playlist )
-            {
-                playlist->makeLoadingSync();
-                playlist->triggerTrackLoad(); //playlist track loading is on demand.
-                //since this is a playlist masqueurading as a single track, make a MultiTrack out of it:
-                if ( playlist->tracks().count() > 0 )
-                    modifiedList << Meta::TrackPtr( new Meta::MultiTrack( playlist ) );
-            }
+            /*ignore*/
         }
         else if( typeid( *track.data() ) == typeid( MetaFile::Track  ) )
         {
