@@ -59,8 +59,6 @@ Playlist::Dock::Dock( QWidget* parent )
     : AmarokDockWidget( i18n( "&Playlist" ), parent )
     , m_barBox( 0 )
 {
-    DEBUG_BLOCK
-
     setObjectName( "Playlist dock" );
     setAllowedAreas( Qt::AllDockWidgetAreas );
 }
@@ -89,13 +87,11 @@ Playlist::Dock::searchWidget()
 void
 Playlist::Dock::polish()
 {
-    DEBUG_BLOCK
-
     m_mainWidget = new KVBox( this );
     setWidget( m_mainWidget );
     m_mainWidget->setContentsMargins( 0, 0, 0, 0 );
     m_mainWidget->setFrameShape( QFrame::NoFrame );
-
+    m_mainWidget->setMinimumWidth( 200 );
     m_mainWidget->setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Ignored );
     m_mainWidget->setFocus( Qt::ActiveWindowFocusReason );
 
@@ -169,7 +165,7 @@ Playlist::Dock::polish()
         // action toolbar
         m_barBox = new KHBox( m_mainWidget );
         m_barBox->setObjectName( "PlaylistBarBox" );
-        m_barBox->setContentsMargins( 0, 0, 0, 0 );
+        m_barBox->setContentsMargins( 0, 0, 4, 0 );
         m_barBox->setFixedHeight( 36 );
 
         // Use QToolBar instead of KToolBar, see bug 228390
@@ -247,9 +243,9 @@ void
 Playlist::Dock::paletteChanged( const QPalette &palette )
 {
     const QString backgroundColor = PaletteHandler::highlightColor().name();
-    const QString textColor = palette.color( QPalette::HighlightedText ).name();
-    const QString linkColor = palette.color( QPalette::Link ).name();
-    const QString ridgeColor = palette.color( QPalette::Window ).name();
+    const QString textColor = palette.color( QPalette::Active, QPalette::HighlightedText ).name();
+    const QString linkColor = palette.color( QPalette::Active, QPalette::Link ).name();
+    const QString ridgeColor = palette.color( QPalette::Active, QPalette::Window ).name();
 
     QString hintStyle( "QLabel { background-color: %1; color: %2; border-radius: 3px; } "
                        "a { color: %3; }" );
