@@ -20,10 +20,15 @@
 #ifndef AMAROKPLAYLISTITEM_H
 #define AMAROKPLAYLISTITEM_H
 
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
+
+#include <QMetaType>
 
 namespace Playlist
 {
+    /** Playlist::Item is used in the playlist model to reference an entry in the playlist.
+        It combines a track with a unique id and a played state.
+    */
     class Item
     {
         public:
@@ -37,11 +42,11 @@ namespace Playlist
 
             static void listRemove( QList<quint64> &target, QSet<quint64> &removeSet );
 
-
-            Item() : m_track ( 0 ), m_state ( Invalid ), m_id ( 0 ) { }
-            Item ( Meta::TrackPtr track );
+            Item();
+            Item( Meta::TrackPtr track );
             ~Item();
-            Meta::TrackPtr track() const { return m_track; }
+
+            const Meta::TrackPtr& track() const;
 
             State state() const { return m_state; }
             void setState ( State s ) { m_state = s; }
@@ -59,6 +64,6 @@ namespace Playlist
     };
 }
 
-Q_DECLARE_METATYPE ( Playlist::Item* )
+Q_DECLARE_METATYPE( Playlist::Item* )
 
 #endif
