@@ -36,7 +36,7 @@ typedef QList<SqlPlaylistGroupPtr> SqlPlaylistGroupList;
 
     @author Nikolaj Hald Nielsen <nhn@kde.org>
 */
-class SqlPlaylist : public Playlist, public Meta::Observer
+class SqlPlaylist : public Playlist
 {
     public:
         SqlPlaylist( const QString &name, const Meta::TrackList &tracks,
@@ -50,7 +50,6 @@ class SqlPlaylist : public Playlist, public Meta::Observer
         /* Playlist virtual functions */
         virtual KUrl uidUrl() const;
         virtual QString name() const { return m_name; }
-        virtual QString description() const { return m_description; }
 
         virtual PlaylistProvider *provider() const { return m_provider; }
 
@@ -59,13 +58,6 @@ class SqlPlaylist : public Playlist, public Meta::Observer
         virtual QStringList groups();
         void setGroups( const QStringList &groups );
 
-        bool saveToDb( bool tracks = true );
-        void setDescription( const QString &description ) { m_description = description; }
-
-        void setParent( SqlPlaylistGroupPtr parent );
-
-        int id();
-
         virtual int trackCount() const;
         virtual Meta::TrackList tracks();
         virtual void triggerTrackLoad();
@@ -73,21 +65,8 @@ class SqlPlaylist : public Playlist, public Meta::Observer
         virtual void addTrack( Meta::TrackPtr track, int position = -1 );
         virtual void removeTrack( int position );
 
-        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const
-                { Q_UNUSED( type ); return false; }
-        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type )
-                { Q_UNUSED( type ); return 0; }
-
-        /* Meta::Observer methods */
-        virtual void metadataChanged( Meta::TrackPtr track );
-        virtual void metadataChanged( Meta::ArtistPtr artist ) { Q_UNUSED( artist ) }
-        virtual void metadataChanged( Meta::AlbumPtr album ) { Q_UNUSED( album ) }
-        virtual void metadataChanged( Meta::GenrePtr genre ) { Q_UNUSED( genre ) }
-        virtual void metadataChanged( Meta::ComposerPtr composer ) { Q_UNUSED( composer ) }
-        virtual void metadataChanged( Meta::YearPtr year ) { Q_UNUSED( year ) }
-
-        SqlPlaylistGroupPtr parent() const;
-
+        // SqlPlaylist-specific methods
+        bool saveToDb( bool tracks = true );
         void removeFromDb();
 
     private:
@@ -99,7 +78,6 @@ class SqlPlaylist : public Playlist, public Meta::Observer
         Meta::TrackList m_tracks;
         PlaylistProvider *m_provider;
         QString m_name;
-        QString m_description;
         QString m_urlId;
 
         bool m_tracksLoaded;
