@@ -19,9 +19,10 @@
 
 #include <KMenu>
 
-#include <QList>
 #include <QObject>
-#include <QtScript>
+#include <QSharedPointer>
+
+class QScriptEngine;
 
 namespace AmarokScript
 {
@@ -31,8 +32,7 @@ namespace AmarokScript
         Q_OBJECT
 
         public:
-            AmarokWindowScript( QScriptEngine* ScriptEngine, QList<QObject*>* guiPtrList );
-            ~AmarokWindowScript();
+            AmarokWindowScript( QScriptEngine* scriptEngine );
 
         public slots:
             bool addToolsMenu( QString id, QString menuTitle, QString icon = "amarok" );
@@ -40,7 +40,11 @@ namespace AmarokScript
             bool addSettingsMenu( QString id, QString menuTitle, QString icon = "amarok" );
             void addSettingsSeparator();
             void showBrowser( QString browser ) const;
-//TODO: show Tray Icon, Show Splash Screen
+            //TODO: show Tray Icon
+
+        signals:
+            void prepareToQuit();
+
         private:
             /**
               * adds an action with the given ID and title to the given menu
@@ -53,13 +57,12 @@ namespace AmarokScript
               *
               * @return true if adding the action was successful, false otherwise
               */
-            bool addMenuAction( KMenu* menu, QString id, QString menuTitle, QString menuProperty, QString icon );
-
-            KMenu*           m_toolsMenu;
-            KMenu*           m_settingsMenu;
-            QScriptEngine*   m_ScriptEngine;
-            QList<QObject*>* m_guiPtrList;
+            bool addMenuAction( QWeakPointer<KMenu> menu, QString id, QString menuTitle, QString menuProperty, QString icon );
 
+            QWeakPointer<KMenu> m_toolsMenu;
+            QWeakPointer<KMenu> m_settingsMenu;
+            QScriptEngine*   m_scriptEngine;
+            QList<QObject*> m_guiPtrList;
     };
 }
 
