@@ -22,6 +22,7 @@
 #include "core/collections/Collection.h"
 #include "core/support/Amarok.h"
 #include "core/support/Debug.h"
+#include "core-impl/collections/support/CollectionManager.h"
 #include "widgets/SearchWidget.h"
 
 #include <KHBox>
@@ -36,6 +37,8 @@ ServiceFactory::ServiceFactory( QObject *parent, const QVariantList &args )
 {
     m_type = Plugins::PluginFactory::Service;
     CollectionManager::instance()->addTrackProvider( this );
+    connect( this, SIGNAL(newService(ServiceBase*)), SLOT(slotNewService(ServiceBase*)) );
+    connect( this, SIGNAL(removeService(ServiceBase*)), SLOT(slotRemoveService(ServiceBase*)) );
 }
 
 ServiceFactory::~ServiceFactory()
@@ -45,35 +48,32 @@ ServiceFactory::~ServiceFactory()
 
 
 Meta::TrackPtr
-ServiceFactory::trackForUrl(const KUrl & url)
+ServiceFactory::trackForUrl( const KUrl &url )
 {
     if ( m_activeServices.size() == 0 ) {
         debug() << "our service (" << name() << ") is needed for a url, so init it!";
         init();
     }
 
-    /*Meta::ServiceTrack * serviceTrack = new Meta::ServiceTrack();
-    serviceTrack->setUidUrl( url.url() );
-    Meta::TrackPtr track( serviceTrack );*/
-
-    Meta::TrackPtr track;
-    foreach( ServiceBase * service, m_activeServices )
+    foreach( ServiceBase *service, m_activeServices )
     {
-        if( !service->serviceReady() ){
+        if( !service->serviceReady() )
+        {
             debug() << "our service is not ready! queuing track and returning proxy";
-            MetaProxy::Track* ptrack = new MetaProxy::Track( url.url(), true );
+            MetaProxy::Track *ptrack = new MetaProxy::Track( url, MetaProxy::Track::ManualLookup );
             MetaProxy::TrackPtr trackptr( ptrack );
             m_tracksToLocate.enqueue( trackptr );
             return Meta::TrackPtr::staticCast( trackptr );
-        } else if (  service->collection() ) {
-            debug() << "Service Ready. Collection is: " << service->collection();
-            track = service->collection()->trackForUrl( url );
         }
-
-        if ( track )
-            return track;
+        else if( service->collection() )
+        {
+            debug() << "Service Ready. Collection is: " << service->collection();
+            return service->collection()->trackForUrl( url );
+        }
+        else
+            warning() << __PRETTY_FUNCTION__ << "service is ready, but service->collection() is null!";
     }
-    return track;
+    return Meta::TrackPtr();
 }
 
 void ServiceFactory::clearActiveServices()
@@ -86,11 +86,29 @@ void ServiceFactory::slotServiceReady()
     while( !m_tracksToLocate.isEmpty() )
     {
         MetaProxy::TrackPtr track = m_tracksToLocate.dequeue();
-        if( track ) 
-            track->lookupTrack( this );
+        if( !track )
+            continue;
+
+        track->lookupTrack( this );
     }
 }
 
+void
+ServiceFactory::slotNewService( ServiceBase *newService )
+{
+    Q_ASSERT( newService );
+    connect( newService, SIGNAL(ready()), this, SLOT(slotServiceReady()) );
+    m_activeServices << newService;
+}
+
+void
+ServiceFactory::slotRemoveService( ServiceBase *service )
+{
+    Q_ASSERT( service );
+    m_activeServices.remove( service );
+    service->deleteLater();
+}
+
 ServiceBase *ServiceBase::s_instance = 0;
 
 ServiceBase::ServiceBase( const QString &name, ServiceFactory *parent, bool useCollectionTreeView, const QString &prettyName )
@@ -98,10 +116,11 @@ ServiceBase::ServiceBase( const QString &name, ServiceFactory *parent, bool useC
     , m_contentView ( 0 )
     , m_parentFactory( parent )
     , m_polished( false )
-    , m_serviceready( false )
     , m_useCollectionTreeView( useCollectionTreeView )
     , m_infoParser( 0 )
+    , m_serviceready( false )
     , m_model( 0 )
+    , m_filterModel( 0 )
 {
     DEBUG_BLOCK
 
@@ -124,7 +143,7 @@ ServiceBase::ServiceBase( const QString &name, ServiceFactory *parent, bool useC
         m_contentView->sortByColumn ( 0, Qt::AscendingOrder );
         m_contentView->setDragEnabled ( true );
         m_contentView->setDragDropMode ( QAbstractItemView::DragOnly );
-        connect( m_contentView, SIGNAL( itemSelected ( CollectionTreeItem * )  ), this, SLOT( itemSelected( CollectionTreeItem * ) ) );
+        connect( m_contentView, SIGNAL(itemSelected(CollectionTreeItem*)), this, SLOT(itemSelected(CollectionTreeItem*)) );
     }
 
     m_bottomPanel = new KVBox( this );
@@ -148,8 +167,8 @@ ServiceBase::ServiceBase( const QString &name, ServiceFactory *parent, bool useC
 
     m_searchWidget = new SearchWidget( m_topPanel );
     if( m_contentView )
-        connect( m_searchWidget, SIGNAL( filterChanged( const QString & ) ),
-                 m_contentView, SLOT( slotSetFilter( const QString & ) ) );
+        connect( m_searchWidget, SIGNAL(filterChanged(QString)),
+                 m_contentView, SLOT(slotSetFilter(QString)) );
 }
 
 ServiceBase::~ServiceBase()
@@ -173,10 +192,9 @@ ServiceBase::itemActivated ( const QModelIndex & index )
 void
 ServiceBase::setModel( QAbstractItemModel * model )
 {
-    //m_filterModel->setSourceModel( model );
-    //m_contentView->setModel( m_filterModel );
-    m_contentView->setModel( model );
-    m_model  = model;
+    if( m_contentView )
+        m_contentView->setModel( model );
+    m_model = model;
 }
 
 QAbstractItemModel *
@@ -207,6 +225,17 @@ ServiceBase::serviceReady() const
     return m_serviceready;
 }
 
+void
+ServiceBase::setServiceReady( bool newReady )
+{
+    if( newReady == m_serviceready )
+        return; // nothing to do
+
+    m_serviceready = newReady;
+    if( m_serviceready )
+        emit ready();
+}
+
 void
 ServiceBase::infoChanged( const QString &infoHtml )
 {
@@ -294,7 +323,7 @@ ServiceBase::setInfoParser(InfoParserBase * infoParser)
 {
     m_infoParser = infoParser;
 
-    connect ( m_infoParser, SIGNAL( info( QString) ), this, SLOT( infoChanged( QString ) ) );
+    connect ( m_infoParser, SIGNAL(info(QString)), this, SLOT(infoChanged(QString)) );
 }
 
 InfoParserBase *
