@@ -1,6 +1,6 @@
 /****************************************************************************************
  * Copyright (c) 2007 Maximilian Kossick <maximilian.kossick@googlemail.com>            *
- * Copyright (c) 2007 Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>                    *
+ * Copyright (c) 2007 Nikolaj Hald Nielsen <nhn@kde.org>                                *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -23,6 +23,7 @@
 #include "ServiceMetaBase.h"
 #include "ServiceSqlRegistry.h"
 
+namespace Collections {
 
 class AMAROK_EXPORT ServiceSqlCollection : public ServiceCollection
 {
@@ -56,5 +57,7 @@ class AMAROK_EXPORT ServiceSqlCollection : public ServiceCollection
         QString m_prettyName;
 };
 
+} //namespace Collections
+
 #endif /* AMAROK_COLLECTION_SQLCOLLECTION_H */
 
