@@ -41,10 +41,8 @@ class ServiceSqlQueryMaker : public QueryMaker
 
         virtual QueryMaker* setQueryType( QueryType type );
 
-        virtual QueryMaker* setReturnResultAsDataPtrs( bool resultAsDataPtrs );
-
         virtual QueryMaker* addMatch( const Meta::TrackPtr &track );
-        virtual QueryMaker* addMatch( const Meta::ArtistPtr &artist );
+        virtual QueryMaker* addMatch( const Meta::ArtistPtr &artist, ArtistMatchBehaviour behaviour = TrackArtists );
         virtual QueryMaker* addMatch( const Meta::AlbumPtr &album );
         virtual QueryMaker* addMatch( const Meta::ComposerPtr &composer );
         virtual QueryMaker* addMatch( const Meta::GenrePtr &genre );
@@ -60,7 +58,6 @@ class ServiceSqlQueryMaker : public QueryMaker
         virtual QueryMaker* addReturnValue( qint64 value );
         virtual QueryMaker* addReturnFunction( ReturnFunction function, qint64 value );
         virtual QueryMaker* orderBy( qint64 value, bool descending = false );
-        virtual QueryMaker* orderByRandom();
 
         virtual QueryMaker* limitMaxResultSize( int size );
 
@@ -69,7 +66,6 @@ class ServiceSqlQueryMaker : public QueryMaker
         virtual QueryMaker* endAndOr();
 
         virtual QueryMaker* setAlbumQueryMode( AlbumQueryMode mode );
-        virtual QueryMaker* setArtistQueryMode( ArtistQueryMode mode );
 
         QString query();
         QStringList runQuery( const QString &query );
