@@ -14,15 +14,15 @@
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
  ****************************************************************************************/
 
+#define DEBUG_PREFIX "ScriptableServiceQueryMaker"
+
 #include "ScriptableServiceQueryMaker.h"
 
-#include "core/meta/support/MetaConstants.h"
-#include "ScriptableServiceMeta.h"
 #include "ScriptManager.h"
-
-#include "core-impl/collections/support/MemoryMatcher.h"
-
+#include "core/meta/support/MetaConstants.h"
 #include "core/support/Debug.h"
+#include "core-impl/collections/support/MemoryMatcher.h"
+#include "services/scriptable/ScriptableServiceMeta.h"
 
 #include <QTimer>
 
@@ -42,9 +42,9 @@ struct ScriptableServiceQueryMaker::Private {
 };
 
 ScriptableServiceQueryMaker::ScriptableServiceQueryMaker( ScriptableServiceCollection * collection, QString name )
- : DynamicServiceQueryMaker()
- , d( new Private )
-
+    : DynamicServiceQueryMaker()
+    , d( new Private )
+    , m_convertToMultiTracks( false )
 {
     setParent( collection );
     m_collection = collection;
@@ -186,12 +186,12 @@ QueryMaker * ScriptableServiceQueryMaker::addMatch( const Meta::AlbumPtr & album
     return this;
 }
 
-
-void ScriptableServiceQueryMaker::handleResult()
+void
+ScriptableServiceQueryMaker::setConvertToMultiTracks( bool convert )
 {
+    m_convertToMultiTracks = convert;
 }
 
-
 void ScriptableServiceQueryMaker::handleResult( const Meta::GenreList & genres )
 {
     if ( d->maxsize >= 0 && genres.count() > d->maxsize )
@@ -216,18 +216,33 @@ void ScriptableServiceQueryMaker::handleResult( const Meta::ArtistList & artists
         emit newResultReady( artists );
 }
 
-void ScriptableServiceQueryMaker::handleResult( const Meta::TrackList & tracks )
+void ScriptableServiceQueryMaker::handleResult( const Meta::TrackList &tracks )
 {
-    debug() << "Emitting " << tracks.count() << " tracks";
-    if ( d->maxsize >= 0 && tracks.count() > d->maxsize )
-        emit newResultReady( tracks.mid( 0, d->maxsize ) );
+    Meta::TrackList ret;
+    if( m_convertToMultiTracks )
+    {
+        foreach( const Meta::TrackPtr &track, tracks )
+        {
+            using namespace Meta;
+            const ScriptableServiceTrack *serviceTrack =
+                    dynamic_cast<const ScriptableServiceTrack *>( track.data() );
+            if( !serviceTrack )
+            {
+                error() << "failed to convert generic track" << track.data() << "to ScriptableServiceTrack";
+                continue;
+            }
+            ret << serviceTrack->playableTrack();
+        }
+    }
     else
-        emit newResultReady( tracks );
+        ret = tracks;
+
+    if ( d->maxsize >= 0 && ret.count() > d->maxsize )
+        emit newResultReady( ret.mid( 0, d->maxsize ) );
+    else
+        emit newResultReady( ret );
 }
 
-
-
-
 void ScriptableServiceQueryMaker::fetchGenre()
 {
     DEBUG_BLOCK
