@@ -39,6 +39,7 @@ class BreadcrumbItemButton : public Amarok::ElidingButton
 
     public:
         BreadcrumbItemButton( QWidget* parent );
+        BreadcrumbItemButton( const QString &text, QWidget *parent );
         BreadcrumbItemButton( const QIcon &icon, const QString &text, QWidget *parent );
         virtual ~BreadcrumbItemButton();
 
@@ -75,11 +76,9 @@ class BreadcrumbItemMenuButton : public BreadcrumbItemButton
     Q_OBJECT
 
     public:
-        explicit BreadcrumbItemMenuButton(QWidget* parent) : BreadcrumbItemButton(parent) { };
+        explicit BreadcrumbItemMenuButton( QWidget* parent );
         virtual ~BreadcrumbItemMenuButton() { }
 
-        virtual QSize sizeHint() const;
-
     protected:
         virtual void paintEvent(QPaintEvent* event);
 };
