@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (c) 2009 Sven Krohlas <sven@getamarok.com>                  *
+ *   Copyright (c) 2009 Sven Krohlas <sven@asbest-online.de>               *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,7 +20,6 @@
 #include "TestCaseConverter.h"
 
 #include "CaseConverter.h"
-#include "core/support/Debug.h"
 
 #include <QtTest/QTest>
 
@@ -28,9 +27,6 @@
 
 QTEST_KDEMAIN_CORE( TestCaseConverter )
 
-//required for Debug.h
-QMutex Debug::mutex;
-
 TestCaseConverter::TestCaseConverter()
 {
 }
